@@ -300,7 +300,7 @@ smoothAllSetYPoints <- function(smooth.seq, displacement,
 	count <- 1
 	for (i in smooth.seq) {
 		#print(c("i",i))
-		speed <- getSpeedSafe(displacement, i)
+		speed <- getSpeed(displacement, i)
 		accel <- getAccelerationSafe(speed)
 		#speed comes in mm/ms when derivate to accel its mm/ms^2 to convert it to m/s^2 need to *1000 because it's quadratic
 		accel$y <- accel$y * 1000 
