@@ -1167,7 +1167,9 @@ start <- function(op)
 			if(RFDoptions$rfdFunction != "-1")
 				exportModelVectorOnFail = c(exportModelVectorOnFail, NA)
 		}
-		exportModelVectorOnFail = c(exportModelVectorOnFail, NA) 		#impulse
+		impulseOptions = readImpulseOptions(op$drawImpulseOptions)
+		if(impulseOptions$impulseFunction != "-1")
+			exportModelVectorOnFail = c(exportModelVectorOnFail, NA) 		#impulse
 
 		#preparing header row (each set will have this in the result dataframe to be able to combine them)
 		maxAvgWindowSecondsHeader = op$maxAvgWindowSeconds
@@ -1183,7 +1185,6 @@ start <- function(op)
 						RFDoptions$start, RFDoptions$end, sep ="_"))
 		}
 
-		impulseOptions = readImpulseOptions(op$drawImpulseOptions)
 		if(impulseOptions$impulseFunction != "-1")
 			exportNames = c(exportNames, paste("Impulse", impulseOptions$impulseFunction, impulseOptions$type,
 					impulseOptions$start, impulseOptions$end, sep ="_"))
@@ -1226,7 +1227,9 @@ start <- function(op)
 			plotABGraph(pngFile, as.vector(dataFiles$fullURL[i]),
 					dataFiles$decimalChar[i], dataFiles$title[i], dataFiles$exercise[i], paste(dataFiles$date[i], dataFiles$time[i], sep=" "),
 					dataFiles$captureOptions[i], dataFiles$startSample[i], dataFiles$endSample[i],
-					dataFiles$maxAvgForceInWindow[i], dataFiles$maxAvgForceInWindowSampleStart[i], dataFiles$maxAvgForceInWindowSampleEnd[i]
+					dataFiles$maxAvgForceInWindow[i],
+					(dataFiles$maxAvgForceInWindowSampleStart[i] +1), # +1 because the C# count starts at 0 and R at 1
+					(dataFiles$maxAvgForceInWindowSampleEnd[i] +1)
 			)
 
 			if(! modelOk)
