@@ -630,7 +630,8 @@ class ImportSession:
         encoder_exercise.remove_duplicates()
 
         self.destination_db.write(table=encoder_exercise,
-                                  matches_columns=self.destination_db.column_names("EncoderExercise", ["uniqueID"]))
+                                  matches_columns=self.destination_db.column_names("EncoderExercise", ["uniqueID"]),
+                                  avoids_duplicate_column="name")
 
         # Imports Encoder1RM
         encoder_1rm = self.source_db.read(table_name="Encoder1RM",
@@ -707,8 +708,8 @@ class ImportSession:
 
 
         self.destination_db.write(table=forceSensor_exercise,
-                                  matches_columns=self.destination_db.column_names("ForceSensorExercise", ["uniqueID"]))
-
+                                  matches_columns=self.destination_db.column_names("ForceSensorExercise", ["uniqueID"]),
+                                  avoids_duplicate_column="name")
 
         # Imports ForceSensor
         forceSensor = self.source_db.read(table_name="ForceSensor",
@@ -752,7 +753,8 @@ class ImportSession:
 
 
         self.destination_db.write(table=runEncoder_exercise,
-                                  matches_columns=self.destination_db.column_names("RunEncoderExercise", ["uniqueID"]))
+                                  matches_columns=self.destination_db.column_names("RunEncoderExercise", ["uniqueID"]),
+                                  avoids_duplicate_column="name")
 
 
         # Imports RunEncoder
