@@ -53,8 +53,6 @@ class ChronojumpImporter
 
 	Preferences.pythonVersionEnum pythonVersion;
 
-	Gtk.Window parentWindow;
-
 	// Result struct holds the output, error and success operations. It's used to pass
 	// errors from different layers (e.g. executing Python scripts) to the UI layer
 	public struct Result
@@ -73,10 +71,9 @@ class ChronojumpImporter
 
 	// ChronojumpImporter class imports a specific session from sourceFile to destinationFile.
 	// The main method is "import()" which does all the work.
-	public ChronojumpImporter(Gtk.Window parentWindow, string sourceFile, string destinationFile,
+	public ChronojumpImporter(string sourceFile, string destinationFile,
 			int sourceSession, int destinationSession, bool debugToFile, Preferences.pythonVersionEnum pythonVersion)
 	{
-		this.parentWindow = parentWindow;
 		this.sourceFile = sourceFile;
 		this.destinationFile = destinationFile;
 		this.sourceSession = sourceSession;
@@ -178,6 +175,10 @@ LogB.Information("import H ");
 
 		MessageToPulsebar = "Preparing database";
 		string temporarySourceFile = Path.GetTempFileName ();
+		LogB.Information("temporarySourceFile without GetFullPath: " + temporarySourceFile);
+		temporarySourceFile = Path.GetFullPath(temporarySourceFile);
+		LogB.Information("temporarySourceFile after GetFullPath: " + temporarySourceFile);
+
 		File.Copy (sourceFile, temporarySourceFile, true);
 
 		Result sourceDatabaseVersion = getDatabaseVersionFromFile (temporarySourceFile);
@@ -210,6 +211,7 @@ LogB.Information("import I ");
 			LogB.Debug ("chronojump-importer version after update: ", versionAfterUpdate);
 		}
 
+LogB.Information("import J ");
 		MessageToPulsebar = "Starting import";
 		List<string> parameters = new List<string> ();
 		parameters.Add ("--source");
@@ -237,10 +239,12 @@ LogB.Information("import I ");
 		else
 			parameters.Add ("NONE");
 
+LogB.Information("import K ");
 		Result result = executeChronojumpImporter (parameters, pythonVersion);
 
 		MessageToPulsebar = "Done!";
 		File.Delete (temporarySourceFile);
+LogB.Information("import L ");
 
 		return result;
 	}
