@@ -103,20 +103,25 @@ public class RunPhaseInfoManage
 		bool firstPair = true;
 		for(int i = startAt +1; i < list.Count; i +=2)
 		{
+			LogB.Information("At rpim IsStartDoubleContact B pre 1");
 			tcRPI = (RunPhaseInfo) list[i-1];
+			LogB.Information("At rpim IsStartDoubleContact B pre 2");
 			tfRPI = (RunPhaseInfo) list[i];
 
 			LogB.Information("At rpim IsStartDoubleContact B");
 			if(firstPair && ! speedStart) {
+				LogB.Information("At rpim IsStartDoubleContact B 3");
 				//if ! speedStart (started inside), don't count first contact time
 				if(tfRPI.Duration > checkTime)
 					return false;
 			}
 			else {
+				LogB.Information("At rpim IsStartDoubleContact B 4");
 				if(tcRPI.Duration + tfRPI.Duration > checkTime)
 					return false;
 			}
 			firstPair = false;
+			LogB.Information("At rpim IsStartDoubleContact B 5");
 		}
 		LogB.Information("At rpim IsStartDoubleContact C");
 
@@ -509,6 +514,7 @@ public class RunDoubleContact
 }
 
 //decide if use this or inspector
+//TODO: clarify what this class does
 public class RunPhaseTimeList
 {
 	public bool SpeedStart;
@@ -529,14 +535,14 @@ public class RunPhaseTimeList
 		FirstRPIs = 0;
 	}
 	
-	public void AddTC(double timestamp)
+	public void AddTC(int photocell, double timestamp)
 	{
-		listPhaseTime.Add(new PhaseTime(true, timestamp));
+		listPhaseTime.Add(new PhaseTime(photocell, true, timestamp));
 	}
 
-	public void AddTF(double timestamp)
+	public void AddTF(int photocell, double timestamp)
 	{
-		listPhaseTime.Add(new PhaseTime(false, timestamp));
+		listPhaseTime.Add(new PhaseTime(photocell, false, timestamp));
 	}
 
 	public override string ToString()
@@ -564,6 +570,8 @@ public class RunPhaseTimeList
 		List<RunPhaseTimeListObject> list_in = new List<RunPhaseTimeListObject>();
 		int currentMS = 0;
 		int startInMS = -1;
+		int startInPhotocell = -1;
+		int currentPhotocell = -1;
 
 		// 1) create a copy of listPhaseTime in order to do foreach without problems with other thread that adds records
 		//This is problematic (Collection was modified; enumeration operation may not execute) if other thread is changing it:
@@ -603,8 +611,10 @@ public class RunPhaseTimeList
 				LogB.Information("InListForPainting negativeValues = " + negativeValues.ToString());
 			}
 
-			if(pt.IsContact)
+			if(pt.IsContact) {
 				startInMS = currentMS;
+				startInPhotocell = pt.Photocell;
+			}
 			else if(startInMS >= 0)
 			{
 				//see if previous has ended to mark as END or STARTEND
@@ -638,10 +648,13 @@ public class RunPhaseTimeList
 				rptloToAdd = new RunPhaseTimeListObject(
 						currentPhase,
 						startInMS/1000.0,
-						currentMS/1000.0);
+						currentMS/1000.0,
+						startInPhotocell,
+						pt.Photocell);
 			}
 
 			currentMS += Convert.ToInt32(pt.Duration);
+			currentPhotocell = pt.Photocell;
 
 			LogB.Information(string.Format("End of iteration: {0}, pt.IsContact: {1}, startInMS: {2}, currentMS: {3}",
 						count, pt.IsContact, startInMS, currentMS));
@@ -667,7 +680,8 @@ public class RunPhaseTimeList
 			RunPhaseTimeListObject rptloLast = new RunPhaseTimeListObject(
 						RunPhaseTimeListObject.Phases.STARTANDEND,
 						startInMS/1000.0,
-						(startInMS + ptLast.Duration)/1000.0);
+						(startInMS + ptLast.Duration)/1000.0,
+						startInPhotocell, ptLast.Photocell);
 
 			if(rptloToAdd.phase == RunPhaseTimeListObject.Phases.START ||
 					rptloToAdd.phase == RunPhaseTimeListObject.Phases.MIDDLE)
@@ -705,8 +719,14 @@ public class RunPhaseTimeList
 		return str;
 	}
 
+	public List<PhaseTime> ListPhaseTime
+	{
+		get { return listPhaseTime; }
+	}
+
 }
 
+//TODO: clarify what this class does
 public class RunPhaseTimeListObject
 {
 	//each contact can be start of a chunk, middle, end or startandend
@@ -715,27 +735,35 @@ public class RunPhaseTimeListObject
 	public Phases phase;
 	public double tcStart;
 	public double tcEnd;
+	public int photocellStart;
+	public int photocellEnd;
+
 
 	public RunPhaseTimeListObject ()
 	{
 	}
 
-	public RunPhaseTimeListObject (Phases phase, double tcStart, double tcEnd)
+	public RunPhaseTimeListObject (Phases phase,
+			double tcStart, double tcEnd, int photocellStart, int photocellEnd)
 	{
 		this.phase = phase;
 		this.tcStart = tcStart;
 		this.tcEnd = tcEnd;
+		this.photocellStart = photocellStart;
+		this.photocellEnd = photocellEnd;
 	}
 
 	public override string ToString()
 	{
 		return phase.ToString() + ":" +
 			Math.Round(tcStart, 3).ToString() + ":" +
-			Math.Round(tcEnd, 3).ToString();
+			Math.Round(tcEnd, 3).ToString() + ":" +
+			photocellStart.ToString() + ":" +
+			photocellEnd.ToString();
 	}
 }
 
-//currently used for simple runs
+//TODO: clarify what this class does
 public class RunExecuteInspector
 {
 	public enum Types { RUN_SIMPLE, RUN_INTERVAL }
@@ -766,11 +794,12 @@ public class RunExecuteInspector
 
 	//public methods
 
-	public void ChangePhase(Phases phase)
+	//photocell = -1 for not inalambric photocells
+	public void ChangePhase(int photocell, Phases phase)
 	{
-		ChangePhase(phase, "");
+		ChangePhase(photocell, phase, "");
 	}
-	public void ChangePhase(Phases phase, string message)
+	public void ChangePhase(int photocell, Phases phase, string message)
 	{
 		DateTime dt = DateTime.Now;
 
@@ -780,7 +809,7 @@ public class RunExecuteInspector
 			dtEnded = dt;
 		else // (phase == Phases.IN || phases == Phases.OUT)
 		{
-			InOut inOut = new InOut(phase == Phases.IN, dt, message);
+			InOut inOut = new InOut(photocell, phase == Phases.IN, dt, message);
 			listInOut.Add(inOut);
 			//listInOut.Add(new InOut(phase == Phases.IN, dt, message));
 		}
@@ -802,6 +831,7 @@ public class RunExecuteInspector
 	}
 }
 
+//TODO: clarify what this class does
 public class RunChangeImage
 {
 	public enum Types { NONE, RUNNING, PHOTOCELL }
