@@ -35,6 +35,7 @@ public class SprintExport : ExportFiles
 	public SprintExport (
 			Gtk.Notebook notebook,
 			Gtk.ProgressBar progressbar,
+			Gtk.Label labelDiscarded,
 			Gtk.Label labelResult,
 			bool includeImages,
 			int imageWidth, int imageHeight,
@@ -47,7 +48,7 @@ public class SprintExport : ExportFiles
 	{
 		Button_done = new Gtk.Button();
 
-		assignParams(notebook, progressbar, labelResult, includeImages,
+		assignParams(notebook, progressbar, labelDiscarded, labelResult, includeImages,
 				imageWidth, imageHeight, isWindows, personID, sessionID, exportDecimalSeparator);
 
 		this.digitsNumber = digitsNumber;
@@ -134,8 +135,19 @@ public class SprintExport : ExportFiles
 			if(splitTimes.Split(new char[] {';'}).Length < 3)
 				continue;
 
-			// create the export row
+			//discard sprints that are not sprint
+			SprintRGraph sprintRGraph = new SprintRGraph (
+					positions,
+					splitTimes,
+					ps.Weight, 	//TODO: can be more if extra weight
+					ps.Height,
+					"",
+					25);
 
+			 if(! sprintRGraph.IsDataOk())
+				continue;
+
+			// create the export row
 			string title = Util.ChangeSpaceAndMinusForUnderscore(p.Name) + "-" +
 				Util.ChangeSpaceAndMinusForUnderscore(ri.Type);
 
@@ -148,6 +160,9 @@ public class SprintExport : ExportFiles
 			sprge_l.Add(sprge);
 		}
 
+		//discarded = ri_l.Count - sprge_l.Count;
+		//better use discarded below
+
 		Util.FileDelete(RunInterval.GetCSVResultsURL());
 
 		//no data, maybe because all the tests have just two tracks and cannot be processed as sprint
@@ -174,6 +189,15 @@ public class SprintExport : ExportFiles
 		while ( ! ( Util.FileReadable(RunInterval.GetCSVResultsURL()) || cancel ) )
 			;
 
+		//use this discarded because R discards also
+		List<string> setsProcessedByR = Util.ReadFileAsStringList(RunInterval.GetCSVResultsURL());
+		discarded = ri_l.Count - (setsProcessedByR.Count -1); //-1 for the csv header
+		if(setsProcessedByR.Count -1 <= 0)
+		{
+			noData = true;
+			return false;
+		}
+
 		if(cancel)
 			return false;
 
