@@ -211,7 +211,9 @@ public class ForceSensor
 		if(fse.PercentBodyWeight > 0 && personMass > 0)
 			totalMass = fse.PercentBodyWeight * personMass / 100.0;
 
-		//right now only code for non-elastic
+		//TODO: right now only code for non-elastic
+		//so on elastic we do a load after capture
+		//in future show with cairo a graph of raw, and another with resultant and displacement
 		double accel = 0;
 
 		/*
@@ -231,6 +233,8 @@ public class ForceSensor
 		LogB.Information("forceRaw: " + forceRaw.ToString());
 		LogB.Information("totalMass: " + totalMass.ToString());
 		LogB.Information("AngleDefault: " + fse.AngleDefault.ToString());
+		 */
+		/*
 
 		LogB.Information("horiz: " + (Math.Cos(fse.AngleDefault * Math.PI / 180.0) * (forceRaw + totalMass * accel)).ToString());
 		LogB.Information("vertical: " + (Math.Sin(fse.AngleDefault * Math.PI / 180.0) * (forceRaw + totalMass * accel) + totalMass * 9.81).ToString());
@@ -246,13 +250,16 @@ public class ForceSensor
 				);
         */
 
-        double forceResultant = forceRaw  +  totalMass*(accel + 9.81 * Math.Sin(fse.AngleDefault * Math.PI / 180.0));
+		//on 2.2.1 ABS or inverted is not done on forceResultant,
+		//is done on force coming from the sensor
+		if(fsco != CaptureOptions.NORMAL)
+			forceRaw = calculeForceWithCaptureOptions(forceRaw, fsco);
 
+	        double forceResultant = forceRaw  +  totalMass*(accel + 9.81 * Math.Sin(fse.AngleDefault * Math.PI / 180.0));
 
 		//LogB.Information(string.Format("Abs(forceRaw): {0}, totalMass: {1}, forceResultant: {2}",
 		//			Math.Abs(forceRaw), totalMass, forceResultant));
 
-		//return calculeForceWithCaptureOptions(forceResultant, fsco);
 		return forceResultant;
 	}
 	private static double calculeForceWithCaptureOptions(double force, CaptureOptions fsco)
@@ -402,6 +409,14 @@ public class ForceSensor
 		get { return exerciseName; }
 		set { exerciseName = value; }
 	}
+	public double MaxForceRaw
+	{
+		set { maxForceRaw = value; }
+	}
+	public double MaxAvgForce1s
+	{
+		set { maxAvgForce1s = value; }
+	}
 }
 
 public class ForceSensorExercise
@@ -1020,13 +1035,13 @@ public class ForceSensorCapturePoints
 	//startAtSample is to make algorithm more efficient
 	public int GetSampleOrPreviousAtTimeUs (int us, int startAtSample)
 	{
-		LogB.Information(string.Format("us {0}, startAtSample {1}, times.Count {2} ",
-					us, startAtSample, times.Count));
+		//LogB.Information(string.Format("us {0}, startAtSample {1}, times.Count {2} ",
+		//			us, startAtSample, times.Count));
 		int lastPos = startAtSample;
 		for(int i = startAtSample; i < times.Count; i ++)
 		{
-			LogB.Information(string.Format("i {0}, times[i] {1}, lastPos {2}",
-						i, times[i], lastPos));
+			//LogB.Information(string.Format("i {0}, times[i] {1}, lastPos {2}",
+			//			i, times[i], lastPos));
 			if(times[i] > us)
 				return lastPos;
 
@@ -1035,7 +1050,7 @@ public class ForceSensorCapturePoints
 				lastPos ++;
 		}
 
-		LogB.Information(string.Format("lastPos {0}", lastPos));
+		//LogB.Information(string.Format("lastPos {0}", lastPos));
 		return lastPos;
 	}
 
@@ -1870,7 +1885,7 @@ public class ForceSensorGraphABExport: ForceSensorGraphAB
 			"\"\";\"\";" + 	// triggers unused on export
 			startSample.ToString() + ";" +
 			endSample.ToString() + ";" +
-			Util.RemoveChar(commentOfSet, ';');  //TODO: check this really removes
+			Util.RemoveNewLine(Util.RemoveChar(commentOfSet, ';'), true);
 	}
 
 	public static string PrintCSVHeaderOnExport()
