@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2022   Xavier de Blas <xaviblas@gmail.com>
  */
 
 
@@ -31,8 +31,26 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Button button_combo_select_contacts_top_left;
 	[Widget] Gtk.Button button_combo_select_contacts_top_right;
 	[Widget] Gtk.Button button_contacts_exercise;
+	[Widget] Gtk.Frame frame_image_test;
 	[Widget] Gtk.Label label_contacts_exercise_selected_name;
 	[Widget] Gtk.Label label_contacts_exercise_selected_options;
+	[Widget] Gtk.HBox hbox_contacts_exercise_actions;
+	[Widget] Gtk.Button button_contacts_exercise_actions_edit_do;
+	[Widget] Gtk.Button button_contacts_exercise_actions_add_do;
+	[Widget] Gtk.Label label_contacts_exercise_error;
+
+	private void update_combo_select_contacts_top_using_combo (Gtk.ComboBox cb)
+	{
+		if(combo_select_contacts_top == null)
+			return;
+
+		comboSelectContactsTopNoFollow = true;
+
+		UtilGtk.ComboUpdate(combo_select_contacts_top, UtilGtk.ComboGetValues (cb), "");
+		combo_select_contacts_top.Active = cb.Active;
+
+		comboSelectContactsTopNoFollow = false;
+	}
 
 	private void on_button_contacts_exercise_clicked (object o, EventArgs args)
 	{
@@ -45,6 +63,11 @@ public partial class ChronoJumpWindow
 		hbox_contacts_sup_capture_analyze_two_buttons.Sensitive = false;
 		hbox_top_person.Sensitive = false;
 
+		//do not show the image on runEncoder
+		frame_image_test.Visible = (current_mode != Constants.Modes.RUNSENCODER);
+
+		frame_run_encoder_exercise.Visible = false; //TODO: implement more modes in the future
+
 		button_contacts_exercise_close_and_capture.Sensitive = myTreeViewPersons.IsThereAnyRecord();
 		notebook_contacts_execute_or.CurrentPage = Convert.ToInt32(notebook_contacts_execute_or_pages.INSTRUCTIONS);
 	}
@@ -302,6 +325,57 @@ public partial class ChronoJumpWindow
 					button_combo_force_sensor_exercise_capture_left,
 					button_combo_force_sensor_exercise_capture_right);
 	}
+
+
+	// ---- start of manage exercise edit/add from the app1.glade ---->
+
+	private void show_contacts_exercise_add_edit (bool adding)
+	{
+		notebook_execute.Sensitive = false;
+		frame_run_encoder_exercise.Visible = true; //TODO: in the future implement more modes
+		hbox_contacts_exercise_actions.Sensitive = false;
+		notebook_options_top.Visible = false;
+		label_contacts_exercise_error.Text = "";
+
+
+		if(adding) {
+			button_contacts_exercise_actions_edit_do.Visible = false;
+			button_contacts_exercise_actions_add_do.Visible = true;
+		} else {
+			button_contacts_exercise_actions_edit_do.Visible = true;
+			button_contacts_exercise_actions_add_do.Visible = false;
+		}
+	}
+
+	private void hide_contacts_exercise_add_edit ()
+	{
+		notebook_execute.Sensitive = true;
+		frame_run_encoder_exercise.Visible = false;
+		hbox_contacts_exercise_actions.Sensitive = true;
+		notebook_options_top.Visible = true;
+	}
+
+	private void on_button_contacts_exercise_actions_cancel_clicked (object o, EventArgs args)
+	{
+		hide_contacts_exercise_add_edit ();
+	}
+
+	private void on_button_contacts_exercise_actions_edit_do_clicked (object o, EventArgs args)
+	{
+		if(current_mode == Constants.Modes.RUNSENCODER)
+			if(run_encoder_exercise_do_add_or_edit (false))
+				hide_contacts_exercise_add_edit ();
+	}
+
+	private void on_button_contacts_exercise_actions_add_do_clicked (object o, EventArgs args)
+	{
+		if(current_mode == Constants.Modes.RUNSENCODER)
+			if(run_encoder_exercise_do_add_or_edit (true))
+				hide_contacts_exercise_add_edit ();
+	}
+
+	// <---- end of manage exercise edit/add from the app1.glade ----
+
 }
 
 public class ContactsCaptureDisplay : BooleansInt
