@@ -33,9 +33,11 @@ public partial class ChronoJumpWindow
 	//analyze tab
 	[Widget] Gtk.RadioButton radio_force_sensor_analyze_individual_current_set;
 	[Widget] Gtk.RadioButton radio_force_sensor_analyze_individual_current_session;
+	[Widget] Gtk.RadioButton radio_force_sensor_analyze_individual_all_sessions;
 	[Widget] Gtk.RadioButton radio_force_sensor_analyze_groupal_current_session;
 	[Widget] Gtk.Image image_force_sensor_analyze_individual_current_set;
 	[Widget] Gtk.Image image_force_sensor_analyze_individual_current_session;
+	[Widget] Gtk.Image image_force_sensor_analyze_individual_all_sessions;
 	[Widget] Gtk.Image image_force_sensor_analyze_groupal_current_session;
 
 	[Widget] Gtk.Notebook notebook_force_sensor_analyze_top;
@@ -47,7 +49,7 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Viewport viewport_force_sensor_graph;
 	[Widget] Gtk.Button button_force_sensor_image_save_rfd_auto;
 	[Widget] Gtk.Button button_force_sensor_image_save_rfd_manual;
-	[Widget] Gtk.ScrolledWindow scrolledwindow_force_sensor_ai;
+	//[Widget] Gtk.ScrolledWindow scrolledwindow_force_sensor_ai;
 	[Widget] Gtk.Button button_force_sensor_analyze_AB_save;
 	[Widget] Gtk.CheckButton check_force_sensor_ai_chained;
 	[Widget] Gtk.CheckButton check_force_sensor_ai_zoom;
@@ -181,7 +183,6 @@ public partial class ChronoJumpWindow
 			button_force_sensor_analyze_analyze.Sensitive = false;
 		}
 
-		viewport_persons.Sensitive = s;
 		menus_and_mode_sensitive(s);
 		hbox_contacts_sup_capture_analyze_two_buttons.Sensitive = s;
 		hbox_top_person.Sensitive = s;
@@ -649,7 +650,7 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Label label_force_sensor_ai_speed_a;
 	[Widget] Gtk.Label label_force_sensor_ai_accel_a;
 	[Widget] Gtk.Label label_force_sensor_ai_power_a;
-	[Widget] Gtk.HBox hbox_buttons_scale_force_sensor_ai_b;
+	//[Widget] Gtk.HBox hbox_buttons_scale_force_sensor_ai_b;
 	[Widget] Gtk.Label label_force_sensor_ai_position_b;
 	[Widget] Gtk.Label label_force_sensor_ai_position_diff;
 	[Widget] Gtk.Label label_force_sensor_ai_speed_b;
@@ -709,7 +710,7 @@ public partial class ChronoJumpWindow
 		label_force_sensor_export_result.Text = "";
 		button_force_sensor_export_result_open.Visible = false;
 	}
-	private void on_radio_force_sensor_analyze_individual_current_session_toggled (object o, EventArgs args)
+	private void on_radio_force_sensor_analyze_individual_session_current_or_all_toggled (object o, EventArgs args)
 	{
 		button_force_sensor_analyze_load.Visible = false;
 
@@ -733,8 +734,20 @@ public partial class ChronoJumpWindow
 		button_force_sensor_export_result_open.Visible = false;
 	}
 
-	private void on_button_force_sensor_export_current_session_clicked (object o, EventArgs args)
+	//everything except the current set
+	private void on_button_force_sensor_export_not_set_clicked (object o, EventArgs args)
 	{
+		// 1) check if all sessions
+		if(radio_force_sensor_analyze_individual_all_sessions.Active)
+		{
+			if(currentPerson == null)
+				return;
+
+			button_force_sensor_export_session (currentPerson.UniqueID, -1);
+			return;
+		}
+
+		// 2) current session (individual or groupal)
 		if(currentSession == null)
 			return;
 
@@ -743,16 +756,16 @@ public partial class ChronoJumpWindow
 			if(currentPerson == null)
 				return;
 
-			button_force_sensor_export_session (currentPerson.UniqueID);
+			button_force_sensor_export_session (currentPerson.UniqueID, currentSession.UniqueID);
 		}
 		else if (radio_force_sensor_analyze_groupal_current_session.Active)
 		{
-			button_force_sensor_export_session (-1);
+			button_force_sensor_export_session (-1, currentSession.UniqueID);
 		}
 	}
 
 	ForceSensorExport forceSensorExport;
-	private void button_force_sensor_export_session (int personID)
+	private void button_force_sensor_export_session (int personID, int sessionID)
 	{
 		double duration = -1;
 		if(radio_force_duration_seconds.Active)
@@ -790,7 +803,7 @@ public partial class ChronoJumpWindow
 				check_force_sensor_export_images.Active,
 				Convert.ToInt32(spinbutton_force_sensor_export_image_width.Value),
 				Convert.ToInt32(spinbutton_force_sensor_export_image_height.Value),
-				UtilAll.IsWindows(), personID, currentSession.UniqueID,
+				UtilAll.IsWindows(), personID, sessionID,
 				rfdList, impulse,//getImpulseValue(),
 				duration, Convert.ToInt32(spin_force_rfd_duration_percent.Value),
 				preferences.forceSensorElasticEccMinDispl,
@@ -810,11 +823,15 @@ public partial class ChronoJumpWindow
 		{
 			if(personID == -1)
 				selectedFile = checkFolder (Constants.CheckFileOp.FORCESENSOR_EXPORT_GROUPAL_CURRENT_SESSION_YES_IMAGES);
+			else if (sessionID == -1)
+				selectedFile = checkFolder (Constants.CheckFileOp.FORCESENSOR_EXPORT_INDIVIDUAL_ALL_SESSIONS_YES_IMAGES);
 			else
 				selectedFile = checkFolder (Constants.CheckFileOp.FORCESENSOR_EXPORT_INDIVIDUAL_CURRENT_SESSION_YES_IMAGES);
 		} else {
 			if(personID == -1)
 				selectedFile = checkFile (Constants.CheckFileOp.FORCESENSOR_EXPORT_GROUPAL_CURRENT_SESSION_NO_IMAGES);
+			else if (sessionID == -1)
+				selectedFile = checkFile (Constants.CheckFileOp.FORCESENSOR_EXPORT_INDIVIDUAL_ALL_SESSIONS_NO_IMAGES);
 			else
 				selectedFile = checkFile (Constants.CheckFileOp.FORCESENSOR_EXPORT_INDIVIDUAL_CURRENT_SESSION_NO_IMAGES);
 		}
@@ -886,10 +903,11 @@ public partial class ChronoJumpWindow
 			int secondValue = Convert.ToInt32(hscale_force_sensor_ai_b.Value);
 			//LogB.Information(string.Format("firstValue: {0}, secondValue: {1}", firstValue, secondValue));
 
+			//note that is almost impossible in the ui, but just in case...
 			if(firstValue > secondValue) {
 				int temp = firstValue;
 				firstValue = secondValue;
-				secondValue = firstValue;
+				secondValue = temp;
 			}
 
 			//-1 and +1 to have the points at the edges to calcule the RFDs
@@ -1408,7 +1426,7 @@ public partial class ChronoJumpWindow
 		// 2b) draw horizontal 0 line on elastic, and Y right axis
 		if(fsAI.CalculedElasticPSAP)
 		{
-			int yPx = fsAI.FscAIPoints.GetForceInPx(0);
+			//int yPx = fsAI.FscAIPoints.GetForceInPx(0);
 
 			layout_force_ai_text.SetMarkup("Displ (m)");
 			layout_force_ai_text.GetPixelSize(out textWidth, out textHeight);
