@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2017-2021   Xavier de Blas <xaviblas@gmail.com>
+ * Copyright (C) 2017-2022   Xavier de Blas <xaviblas@gmail.com>
  */
 
 
@@ -79,6 +79,9 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_add_test5;
 	[Widget] Gtk.Image image_test_inspect;
 	[Widget] Gtk.Image image_test_inspect1;
+	[Widget] Gtk.Image image_button_contacts_exercise_actions_cancel;
+	[Widget] Gtk.Image image_button_contacts_exercise_actions_edit_do;
+	[Widget] Gtk.Image image_button_contacts_exercise_actions_add_do;
 
 	[Widget] Gtk.Image image_logo_contacts;
 	[Widget] Gtk.Image image_logo_contacts_transp;
@@ -119,14 +122,11 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_edit_selected_reaction_time;
 	[Widget] Gtk.Image image_edit_selected_multi_chronopic;
 
-	//jumps
-	[Widget] Gtk.Image image_button_jumps_simple_capture_save_image_chart;
-	[Widget] Gtk.Image image_button_jumps_simple_capture_save_image_disk;
+	[Widget] Gtk.Image image_button_contacts_capture_save_image_chart;
+	[Widget] Gtk.Image image_button_contacts_capture_save_image_disk;
 
 	//run
 	[Widget] Gtk.Image image_run_simple_show_time;
-	[Widget] Gtk.Image image_button_runs_simple_capture_save_image_chart;
-	[Widget] Gtk.Image image_button_runs_simple_capture_save_image_disk;
 	[Widget] Gtk.Image image_run_execute_running;
 	[Widget] Gtk.Image image_run_execute_photocell;
 	[Widget] Gtk.Image image_sprint_analyze_save;
@@ -224,6 +224,8 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_hscale_force_sensor_ai_b_post_1s;
 
 	//race encoder
+	[Widget] Gtk.Image image_button_contacts_run_encoder_capture_save_image_chart;
+	[Widget] Gtk.Image image_button_contacts_run_encoder_capture_save_image_disk;
 	[Widget] Gtk.Image image_run_encoder_exercise_edit;
 	[Widget] Gtk.Image image_run_encoder_exercise_add;
 	[Widget] Gtk.Image image_run_encoder_exercise_delete;
@@ -231,6 +233,7 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_run_encoder_analyze_image_save_graph;
 	[Widget] Gtk.Image image_run_encoder_analyze_image_save_disk;
 	[Widget] Gtk.Image image_run_encoder_export_cancel;
+	[Widget] Gtk.Image image_run_encoder_exercise_is_sprint_help;
 
 	//video play icons
 	[Widget] Gtk.Image image_video_play_this_test_contacts;
@@ -437,6 +440,7 @@ public partial class ChronoJumpWindow
 		image_info4.Pixbuf = pixbuf;
 		image_run_simple_with_reaction_time_help.Pixbuf = pixbuf;
 		image_run_interval_with_reaction_time_help.Pixbuf = pixbuf;
+		image_run_encoder_exercise_is_sprint_help.Pixbuf = pixbuf;
 		image_info_sessions_info.Pixbuf = pixbuf;
 		image_encoder_1RM_info.Pixbuf = pixbuf;
 		image_force_sensor_adjust_help.Pixbuf = pixbuf;
@@ -771,6 +775,7 @@ public partial class ChronoJumpWindow
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_cancel.png");
 		image_sprint_export_cancel.Pixbuf = pixbuf;
+		image_button_contacts_exercise_actions_cancel.Pixbuf = pixbuf;
 		image_button_encoder_exercise_actions_cancel.Pixbuf = pixbuf;
 		image_encoder_analyze_cancel.Pixbuf = pixbuf;
 		image_force_sensor_export_cancel.Pixbuf = pixbuf;
@@ -835,9 +840,9 @@ public partial class ChronoJumpWindow
 		UtilGtk.ColorsCheckbox(viewport_chronopics, check_encoder_analyze_show_time_to_peak_power);
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_analyze.png");
-		image_button_jumps_simple_capture_save_image_chart.Pixbuf = pixbuf;
-		image_button_runs_simple_capture_save_image_chart.Pixbuf = pixbuf;
+		image_button_contacts_capture_save_image_chart.Pixbuf = pixbuf;
 		image_encoder_analyze_stats.Pixbuf = pixbuf;
+		image_encoder_analyze_mode_options_close_and_analyze.Pixbuf = pixbuf;
 		image_encoder_capture_image_save.Pixbuf = pixbuf;
 		image_encoder_analyze_image_save.Pixbuf = pixbuf;
 		image_forcesensor_analyze_save_signal.Pixbuf = pixbuf;
@@ -854,14 +859,16 @@ public partial class ChronoJumpWindow
 		image_runs_evolution_save.Pixbuf = pixbuf;
 		image_jumps_rj_fatigue_save.Pixbuf = pixbuf;
 		image_sprint_analyze_save.Pixbuf = pixbuf;
+		image_button_contacts_run_encoder_capture_save_image_chart.Pixbuf = pixbuf;
 		image_encoder_analyze_image_compujump_send_email_image.Pixbuf = pixbuf;
 		image_run_encoder_analyze_image_save_graph.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "save.png");
-		image_button_jumps_simple_capture_save_image_disk.Pixbuf = pixbuf;
-		image_button_runs_simple_capture_save_image_disk.Pixbuf = pixbuf;
+		image_button_contacts_capture_save_image_disk.Pixbuf = pixbuf;
 		image_jumps_rj_fatigue_image_save.Pixbuf = pixbuf;
 		image_sprint_analyze_table_save_1.Pixbuf = pixbuf;
+		image_button_contacts_exercise_actions_edit_do.Pixbuf = pixbuf;
+		image_button_contacts_exercise_actions_add_do.Pixbuf = pixbuf;
 		image_button_encoder_exercise_actions_edit_do.Pixbuf = pixbuf;
 		image_button_encoder_exercise_actions_add_do.Pixbuf = pixbuf;
 		image_encoder_capture_curves_save.Pixbuf = pixbuf;
@@ -880,6 +887,7 @@ public partial class ChronoJumpWindow
 		image_forcesensor_analyze_image_save7.Pixbuf = pixbuf;
 		image_runs_evolution_analyze_image_save.Pixbuf = pixbuf;
 		image_force_sensor_analyze_table_save_1.Pixbuf = pixbuf;
+		image_button_contacts_run_encoder_capture_save_image_disk.Pixbuf = pixbuf;
 		image_run_encoder_analyze_table_save_1.Pixbuf = pixbuf;
 		image_sprint_analyze_image_save.Pixbuf = pixbuf;
 		image_run_encoder_analyze_image_save_disk.Pixbuf = pixbuf;
