@@ -66,7 +66,7 @@ public partial class ChronoJumpWindow
 	}
 	private void on_combo_select_jumps_rj_fatigue_changed (object o, EventArgs args)
 	{
-		ComboBox combo = o as ComboBox;
+		//ComboBox combo = o as ComboBox;
 		if (o == null)
 			return;
 
@@ -94,7 +94,7 @@ public partial class ChronoJumpWindow
 	}
 	private void on_combo_select_jumps_rj_fatigue_num_changed (object o, EventArgs args)
 	{
-		ComboBox combo = o as ComboBox;
+		//ComboBox combo = o as ComboBox;
 		if (o == null)
 			return;
 
@@ -132,7 +132,7 @@ public partial class ChronoJumpWindow
 			return types;
 
 		List <JumpRj> jrj_l = SqliteJumpRj.SelectJumps (false, currentSession.UniqueID, currentPerson.UniqueID,
-				comboSelectJumpsRjFatigue.GetSelectedNameEnglish());
+				comboSelectJumpsRjFatigue.GetSelectedNameEnglish(), Sqlite.Orders_by.DEFAULT, -1, false);
 
 		int count = 1;
 		foreach(JumpRj jrj in jrj_l)
