@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2018-2020   Xavier de Blas <xaviblas@gmail.com>
+ * Copyright (C) 2018-2022   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
@@ -61,6 +61,58 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.DrawingArea drawingarea_race_analyzer_capture_position_time;
 	[Widget] Gtk.DrawingArea drawingarea_race_analyzer_capture_speed_time;
 	[Widget] Gtk.DrawingArea drawingarea_race_analyzer_capture_accel_time;
+	[Widget] Gtk.VBox vbox_race_analyzer_capture_graphs;
+
+	[Widget] Gtk.Frame frame_run_encoder_exercise;
+	[Widget] Gtk.Entry entry_run_encoder_exercise_name;
+	[Widget] Gtk.Entry entry_run_encoder_exercise_description;
+	[Widget] Gtk.CheckButton check_run_encoder_exercise_is_sprint;
+	[Widget] Gtk.CheckButton check_run_encoder_exercise_fixed_size;
+	[Widget] Gtk.HBox hbox_run_encoder_exercise_fixed_segments_size;
+	[Widget] Gtk.HBox hbox_run_encoder_exercise_notfixed_segment_num;
+	[Widget] Gtk.SpinButton	spin_race_encoder_exercise_f_segment_size_cm; //f: fixed
+	[Widget] Gtk.SpinButton spin_race_encoder_exercise_v_segments_num; //v: variable
+	[Widget] Gtk.Frame frame_run_encoder_exercise_notfixed_segments;
+	[Widget] Gtk.SpinButton spin_race_encoder_exercise_v_segment_size_cm_0; //v: variable
+	[Widget] Gtk.SpinButton spin_race_encoder_exercise_v_segment_size_cm_1;
+	[Widget] Gtk.SpinButton spin_race_encoder_exercise_v_segment_size_cm_2;
+	[Widget] Gtk.SpinButton spin_race_encoder_exercise_v_segment_size_cm_3;
+	[Widget] Gtk.SpinButton spin_race_encoder_exercise_v_segment_size_cm_4;
+	[Widget] Gtk.SpinButton spin_race_encoder_exercise_v_segment_size_cm_5;
+	[Widget] Gtk.SpinButton spin_race_encoder_exercise_v_segment_size_cm_6;
+	[Widget] Gtk.SpinButton spin_race_encoder_exercise_v_segment_size_cm_7;
+	[Widget] Gtk.SpinButton spin_race_encoder_exercise_v_segment_size_cm_8;
+	[Widget] Gtk.SpinButton spin_race_encoder_exercise_v_segment_size_cm_9;
+	[Widget] Gtk.SpinButton spin_race_encoder_exercise_v_segment_size_cm_10;
+	[Widget] Gtk.SpinButton spin_race_encoder_exercise_v_segment_size_cm_11;
+	[Widget] Gtk.SpinButton spin_race_encoder_exercise_v_segment_size_cm_12;
+	[Widget] Gtk.SpinButton spin_race_encoder_exercise_v_segment_size_cm_13;
+	[Widget] Gtk.SpinButton spin_race_encoder_exercise_v_segment_size_cm_14;
+	[Widget] Gtk.SpinButton spin_race_encoder_exercise_v_segment_size_cm_15;
+	[Widget] Gtk.SpinButton spin_race_encoder_exercise_v_segment_size_cm_16;
+	[Widget] Gtk.SpinButton spin_race_encoder_exercise_v_segment_size_cm_17;
+	[Widget] Gtk.SpinButton spin_race_encoder_exercise_v_segment_size_cm_18;
+	[Widget] Gtk.SpinButton spin_race_encoder_exercise_v_segment_size_cm_19;
+	[Widget] Gtk.SpinButton spin_race_encoder_exercise_v_segment_size_cm_20;
+	[Widget] Gtk.SpinButton spin_race_encoder_exercise_v_segment_size_cm_21;
+	[Widget] Gtk.SpinButton spin_race_encoder_exercise_v_segment_size_cm_22;
+	[Widget] Gtk.SpinButton spin_race_encoder_exercise_v_segment_size_cm_23;
+	[Widget] Gtk.SpinButton spin_race_encoder_exercise_v_segment_size_cm_24;
+	[Widget] Gtk.SpinButton spin_race_encoder_exercise_v_segment_size_cm_25;
+	[Widget] Gtk.SpinButton spin_race_encoder_exercise_v_segment_size_cm_26;
+	[Widget] Gtk.SpinButton spin_race_encoder_exercise_v_segment_size_cm_27;
+	[Widget] Gtk.SpinButton spin_race_encoder_exercise_v_segment_size_cm_28;
+	[Widget] Gtk.SpinButton spin_race_encoder_exercise_v_segment_size_cm_29;
+	[Widget] Gtk.SpinButton spin_race_encoder_exercise_v_segment_size_cm_30;
+	[Widget] Gtk.SpinButton spin_race_encoder_exercise_v_segment_size_cm_31;
+	[Widget] Gtk.SpinButton spin_race_encoder_exercise_v_segment_size_cm_32;
+	[Widget] Gtk.SpinButton spin_race_encoder_exercise_v_segment_size_cm_33;
+	[Widget] Gtk.SpinButton spin_race_encoder_exercise_v_segment_size_cm_34;
+	[Widget] Gtk.SpinButton spin_race_encoder_exercise_v_segment_size_cm_35;
+	[Widget] Gtk.SpinButton spin_race_encoder_exercise_v_segment_size_cm_36;
+	[Widget] Gtk.SpinButton spin_race_encoder_exercise_v_segment_size_cm_37;
+	[Widget] Gtk.SpinButton spin_race_encoder_exercise_v_segment_size_cm_38;
+	[Widget] Gtk.SpinButton spin_race_encoder_exercise_v_segment_size_cm_39;
 
 	int race_analyzer_distance;
 	int race_analyzer_temperature;
@@ -326,6 +378,11 @@ public partial class ChronoJumpWindow
 		cairoGraphRaceAnalyzerPoints_st_l = new List<PointF>();
 		cairoGraphRaceAnalyzerPoints_at_l = new List<PointF>();
 
+		//to not show old vertical segments info on a capture that maybe cannot be done by lack of device
+		if(currentRunEncoderExercise != null)
+			reCGSD = new RunEncoderCaptureGetSpeedAndDisplacement(
+					currentRunEncoderExercise.SegmentCm, currentRunEncoderExercise.SegmentVariableCm);
+
 		updateRaceAnalyzerCapturePositionTime(true);
 		updateRaceAnalyzerCaptureSpeedTime(true);
 		updateRaceAnalyzerCaptureAccelTime(true);
@@ -398,7 +455,8 @@ public partial class ChronoJumpWindow
 
 		treeview_raceAnalyzer = UtilGtk.RemoveColumns(treeview_raceAnalyzer);
 		button_raceAnalyzer_table_save.Sensitive = false;
-		clearRaceAnalyzerTriggers();
+		triggerListRunEncoder = new TriggerList();
+		clearRaceAnalyzerTriggersFromTextView();
 
 		button_run_encoder_analyze_options_close_and_analyze.Sensitive = false;
 		button_run_encoder_analyze_analyze.Sensitive = false;
@@ -413,6 +471,7 @@ public partial class ChronoJumpWindow
 				label_run_encoder_export_data.Text = "";
 		}
 
+		label_run_encoder_export_discarded.Text = "";
 		label_run_encoder_export_result.Text = "";
 		button_run_encoder_export_result_open.Visible = false;
 	}
@@ -467,8 +526,8 @@ public partial class ChronoJumpWindow
 
 	private void assignCurrentRunEncoderExercise()
 	{
-		currentRunEncoderExercise = (RunEncoderExercise) SqliteRunEncoderExercise.Select (
-                                false, getExerciseIDFromAnyCombo(combo_run_encoder_exercise, runEncoderComboExercisesString, false), false)[0];
+		currentRunEncoderExercise = SqliteRunEncoderExercise.Select (
+                                false, getExerciseIDFromAnyCombo(combo_run_encoder_exercise, runEncoderComboExercisesString, false))[0];
 	}
 
 	//TODO: do all this with an "other" thread like in force sensor to allow connecting messages to be displayed
@@ -520,7 +579,8 @@ public partial class ChronoJumpWindow
 		cairoGraphRaceAnalyzerPoints_at_l = new List<PointF>();
 
 		//RunEncoderCaptureGetSpeedAndDisplacement reCGSD = new RunEncoderCaptureGetSpeedAndDisplacement();
-		reCGSD = new RunEncoderCaptureGetSpeedAndDisplacement();
+		reCGSD = new RunEncoderCaptureGetSpeedAndDisplacement(
+				currentRunEncoderExercise.SegmentCm, currentRunEncoderExercise.SegmentVariableCm);
 		runEncoderShouldShowCaptureGraphsWithData = true;
 
 		runEncoderCaptureThread = new Thread(new ThreadStart(runEncoderCaptureDo));
@@ -942,17 +1002,25 @@ public partial class ChronoJumpWindow
 		genericWin.HideAndNull();
 		radio_run_encoder_analyze_individual_current_set.Active = true;
 
+		string str = run_encoder_load_set (uniqueID);
+		if(str != "")
+			event_execute_label_message.Text = Catalog.GetString("Loaded:") + " " + str;
+	}
+
+	//this is also called from recalculate
+	private string run_encoder_load_set (int uniqueID)
+	{
 		RunEncoder re = (RunEncoder) SqliteRunEncoder.Select(false, uniqueID, currentPerson.UniqueID, currentSession.UniqueID)[0];
 		if(re == null)
 		{
 			new DialogMessage(Constants.MessageTypes.WARNING, Constants.FileNotFoundStr());
-			return;
+			return "";
 		}
 
 		if(! Util.FileExists(re.FullURL))
 		{
 			new DialogMessage(Constants.MessageTypes.WARNING, Constants.FileNotFoundStr());
-			return;
+			return "";
 		}
 
 		List<string> contents = Util.ReadFileAsStringList(re.FullURL);
@@ -960,7 +1028,7 @@ public partial class ChronoJumpWindow
 		if(contents.Count < 3)
 		{
 			new DialogMessage(Constants.MessageTypes.WARNING, Constants.FileEmptyStr());
-			return;
+			return "";
 		}
 
 		currentRunEncoder = re;
@@ -988,7 +1056,8 @@ public partial class ChronoJumpWindow
 		// ---- capture tab graphs start ---->
 
 		int count = 0;
-		reCGSD = new RunEncoderCaptureGetSpeedAndDisplacement();
+		reCGSD = new RunEncoderCaptureGetSpeedAndDisplacement(
+				currentRunEncoderExercise.SegmentCm, currentRunEncoderExercise.SegmentVariableCm);
 		runEncoderShouldShowCaptureGraphsWithData = true;
 
 		cairoGraphRaceAnalyzer_dt = null;
@@ -1074,11 +1143,12 @@ public partial class ChronoJumpWindow
 		button_video_play_this_test_contacts.Sensitive = (re.VideoURL != "");
 		sensitiveLastTestButtons(true);
 
-		event_execute_label_message.Text = Catalog.GetString("Loaded:") + " " + Util.GetLastPartOfPath(re.Filename);
 		image_run_encoder_graph.Visible = false;
 		button_run_encoder_analyze_analyze.Sensitive = true;
 		button_run_encoder_analyze_options_close_and_analyze.Sensitive = true;
 		button_run_encoder_image_save.Sensitive = true;
+
+		return (Util.GetLastPartOfPath(re.Filename));
 	}
 
 	protected void on_run_encoder_load_signal_row_play (object o, EventArgs args)
@@ -1219,11 +1289,14 @@ public partial class ChronoJumpWindow
 		assignCurrentRunEncoderExercise();
 
 		raceEncoderReadWidgets();
+
+		//recalculate should not analyze (calling to R) specially if segmentCm is variable.
+		//also recalculate what? current set? all sets on analyze current session
+		/*
 		if(lastRunEncoderFullPath != null && lastRunEncoderFullPath != "")
 			raceEncoderCopyToTempAndDoRGraph();
+			*/
 
-		event_execute_label_message.Text = "Recalculated.";
-		radio_mode_contacts_analyze.Active = true;
 		button_contacts_exercise_close_and_recalculate.Sensitive = true;
 
 		//update SQL with exercise, device, distance, temperature, comments
@@ -1236,6 +1309,10 @@ public partial class ChronoJumpWindow
 		currentRunEncoder.Comments = UtilGtk.TextViewGetCommentValidSQL(textview_contacts_signal_comment);
 
 		currentRunEncoder.UpdateSQL(false);
+
+		string str = run_encoder_load_set (currentRunEncoder.UniqueID);
+		if(str != "")
+			event_execute_label_message.Text = "Recalculated.";
 	}
 
 	private void raceEncoderCopyToTempAndDoRGraph()
@@ -1405,11 +1482,6 @@ public partial class ChronoJumpWindow
 		return recsv;
 	}
 
-	private void on_button_raceAnalyzer_table_save_clicked (object o, EventArgs args)
-	{
-		checkFile(Constants.CheckFileOp.RUNENCODER_SAVE_TABLE);
-	}
-
 	private string readFromRunEncoderIfDataArrived()
 	{
 		string str = "";
@@ -1791,8 +1863,8 @@ public partial class ChronoJumpWindow
 
 	private void fillRunEncoderExerciseCombo(string name)
 	{
-		ArrayList runEncoderExercises = SqliteRunEncoderExercise.Select (false, -1, false);
-		if(runEncoderExercises.Count == 0)
+		List<RunEncoderExercise> runEncoderExercises_l = SqliteRunEncoderExercise.Select (false, -1);
+		if(runEncoderExercises_l.Count == 0)
 		{
 			runEncoderComboExercisesString = new String [0];
 			UtilGtk.ComboUpdate(combo_run_encoder_exercise, new String[0], "");
@@ -1800,10 +1872,10 @@ public partial class ChronoJumpWindow
 			return;
 		}
 
-		runEncoderComboExercisesString = new String [runEncoderExercises.Count];
-		string [] exerciseNamesToCombo = new String [runEncoderExercises.Count];
+		runEncoderComboExercisesString = new String [runEncoderExercises_l.Count];
+		string [] exerciseNamesToCombo = new String [runEncoderExercises_l.Count];
 		int i =0;
-		foreach(RunEncoderExercise ex in runEncoderExercises)
+		foreach(RunEncoderExercise ex in runEncoderExercises_l)
 		{
 			exerciseNamesToCombo[i] = ex.Name;
 			runEncoderComboExercisesString[i] = ex.UniqueID + ":" + ex.Name;
@@ -1817,7 +1889,8 @@ public partial class ChronoJumpWindow
 			combo_run_encoder_exercise.Active = UtilGtk.ComboMakeActive(combo_run_encoder_exercise, name);
 
 		//update also combo_select_contacts_top (but check do not crash on start)
-		if(combo_select_contacts_top != null)
+		//we need the 2nd check because without is, on import if we are on other mode, top combo could have been updated with this mode exercises
+		if(combo_select_contacts_top != null && current_mode == Constants.Modes.RUNSENCODER)
 		{
 			comboSelectContactsTopNoFollow = true;
 			UtilGtk.ComboUpdate(combo_select_contacts_top,
@@ -1827,7 +1900,6 @@ public partial class ChronoJumpWindow
 		}
 	}
 
-	//info is now info and edit (all values can be changed), and detete (there's delete button)
 	void on_button_run_encoder_exercise_edit_clicked (object o, EventArgs args)
 	{
 		if(UtilGtk.ComboGetActive(combo_run_encoder_exercise) == "")
@@ -1836,99 +1908,155 @@ public partial class ChronoJumpWindow
 			return;
 		}
 
-		RunEncoderExercise ex = (RunEncoderExercise) SqliteRunEncoderExercise.Select (
-                                false, getExerciseIDFromAnyCombo(combo_run_encoder_exercise, runEncoderComboExercisesString, false), false)[0];
-
+		RunEncoderExercise ex = SqliteRunEncoderExercise.Select (
+                                false, getExerciseIDFromAnyCombo(combo_run_encoder_exercise, runEncoderComboExercisesString, false))[0];
 		LogB.Information("selected exercise: " + ex.ToString());
 
-		ArrayList bigArray = new ArrayList();
+		show_contacts_exercise_add_edit (false);
+		entry_run_encoder_exercise_name.Text = ex.Name;
+		entry_run_encoder_exercise_description.Text = ex.Description;
+		check_run_encoder_exercise_is_sprint.Active = ex.IsSprint;
 
-		ArrayList a1 = new ArrayList();
-		ArrayList a2 = new ArrayList();
-		ArrayList a3 = new ArrayList();
+		if(v_segments_size_cm_l == null)
+			spin_race_encoder_exercise_v_segment_size_cm_create_list ();
 
-		//0 is the widgget to show; 1 is the editable; 2 id default value
-		a1.Add(Constants.GenericWindowShow.ENTRY); a1.Add(true); a1.Add(ex.Name);
-		bigArray.Add(a1);
-
-		a2.Add(Constants.GenericWindowShow.ENTRY2); a2.Add(true); a2.Add(ex.Description);
-		bigArray.Add(a2);
-
-		a3.Add(Constants.GenericWindowShow.SPININT2); a3.Add(true); a3.Add("");
-		bigArray.Add(a3);
-
-		genericWin = GenericWindow.Show(Catalog.GetString("Exercise"), false,	//don't show now
-				Catalog.GetString("Race analyzer exercise:"), bigArray);
-		genericWin.LabelEntry2 = Catalog.GetString("Description");
-
-		genericWin.ShowButtonCancel(false);
-		genericWin.HideOnAccept = false;
-
-		genericWin.uniqueID = ex.UniqueID;
-		genericWin.LabelSpinInt2 = Catalog.GetString("Segments size (m)");
-		genericWin.SetSpin2Range(1, 30);
-		genericWin.SetSpin2Value(ex.SegmentMeters);
-
-		genericWin.Button_accept.Clicked -= new EventHandler(on_button_run_encoder_exercise_edit_accepted);
-		genericWin.Button_accept.Clicked += new EventHandler(on_button_run_encoder_exercise_edit_accepted);
-		genericWin.ShowNow();
-	}
-
-	private void on_button_run_encoder_exercise_add_clicked (object o, EventArgs args)
-	{
-		ArrayList bigArray = new ArrayList();
-
-		ArrayList a1 = new ArrayList();
-		ArrayList a2 = new ArrayList();
-		ArrayList a3 = new ArrayList();
-
-		//0 is the widgget to show; 1 is the editable; 2 id default value
-		a1.Add(Constants.GenericWindowShow.ENTRY); a1.Add(true); a1.Add("");
-		bigArray.Add(a1);
-
-		a2.Add(Constants.GenericWindowShow.ENTRY2); a2.Add(true); a2.Add("");
-		bigArray.Add(a2);
-
-		a3.Add(Constants.GenericWindowShow.SPININT2); a3.Add(true); a3.Add("");
-		bigArray.Add(a3);
-
-		genericWin = GenericWindow.Show(Catalog.GetString("Exercise"), false,	//don't show now
-				Catalog.GetString("Write the name of the exercise:"), bigArray);
-		genericWin.LabelEntry2 = Catalog.GetString("Description");
-
-		genericWin.SetButtonAcceptLabel(Catalog.GetString("Add"));
-		genericWin.HideOnAccept = false;
-
-		genericWin.LabelSpinInt2 = Catalog.GetString("Segments size (m)");
-		genericWin.SetSpin2Range(1, 30);
-		genericWin.SetSpin2Value(RunEncoderExercise.SegmentMetersDefault);
-
-		genericWin.Button_accept.Clicked -= new EventHandler(on_button_run_encoder_exercise_add_accepted);
-		genericWin.Button_accept.Clicked += new EventHandler(on_button_run_encoder_exercise_add_accepted);
-		genericWin.ShowNow();
-	}
-
-	void on_button_run_encoder_exercise_edit_accepted (object o, EventArgs args)
-	{
-		if(run_encoder_exercise_do_add_or_edit(false))
+		if(ex.SegmentCm < 0)
 		{
-			genericWin.Button_accept.Clicked -= new EventHandler(on_button_run_encoder_exercise_edit_accepted);
-			genericWin.HideAndNull();
+			check_run_encoder_exercise_fixed_size.Active = false;
+			spin_race_encoder_exercise_v_segments_num.Value = ex.SegmentVariableCm.Count;
+
+			int i = 0;
+			foreach(int cm in ex.SegmentVariableCm)
+			{
+				( (Gtk.SpinButton) v_segments_size_cm_l[i]).Value = ex.SegmentVariableCm[i];
+				i ++;
+			}
+		} else {
+			check_run_encoder_exercise_fixed_size.Active = true;
+			spin_race_encoder_exercise_f_segment_size_cm.Value = ex.SegmentCm;
 		}
+		//force managing:
+		on_check_run_encoder_exercise_fixed_size_toggled (new object (), new EventArgs ());
 	}
-	void on_button_run_encoder_exercise_add_accepted (object o, EventArgs args)
+
+	void on_button_run_encoder_exercise_add_clicked (object o, EventArgs args)
 	{
-		if(run_encoder_exercise_do_add_or_edit(true))
+		show_contacts_exercise_add_edit (true);
+
+		entry_run_encoder_exercise_name.Text = "";
+		entry_run_encoder_exercise_description.Text = "";
+		check_run_encoder_exercise_is_sprint.Active = true;
+		spin_race_encoder_exercise_f_segment_size_cm.Value = RunEncoderExercise.SegmentCmDefault;
+		spin_race_encoder_exercise_v_segments_num.Value = 2;
+
+		if(v_segments_size_cm_l == null)
+			spin_race_encoder_exercise_v_segment_size_cm_create_list ();
+
+		spin_race_encoder_exercise_v_segment_size_cm_reset_list (); //put default values;
+
+		check_run_encoder_exercise_fixed_size.Active = true;
+		//force managing:
+		on_check_run_encoder_exercise_fixed_size_toggled (new object (), new EventArgs ());
+	}
+
+	private void on_button_run_encoder_exercise_is_sprint_help_clicked (object o, EventArgs args)
+	{
+		new DialogMessage(Constants.MessageTypes.INFO,
+				Catalog.GetString("In a sprint exercise, maximum acceleration is performed at the beginning and maximum sustained speed at a later time."));
+		return;
+	}
+
+	private void on_check_run_encoder_exercise_fixed_size_toggled (object o, EventArgs args)
+	{
+		if(check_run_encoder_exercise_fixed_size.Active)
 		{
-			genericWin.Button_accept.Clicked -= new EventHandler(on_button_run_encoder_exercise_add_accepted);
-			genericWin.HideAndNull();
+			hbox_run_encoder_exercise_fixed_segments_size.Visible = true;
+			hbox_run_encoder_exercise_notfixed_segment_num.Visible = false;
+			frame_run_encoder_exercise_notfixed_segments.Visible = false;
+		} else {
+			hbox_run_encoder_exercise_fixed_segments_size.Visible = false;
+			hbox_run_encoder_exercise_notfixed_segment_num.Visible = true;
+			frame_run_encoder_exercise_notfixed_segments.Visible = true;
+
+			spin_race_encoder_exercise_v_segment_size_cm_show_needed ();
 		}
 	}
 
-	bool run_encoder_exercise_do_add_or_edit (bool adding)
+	private void on_spin_race_encoder_exercise_v_segments_num_value_changed (object o, EventArgs args)
 	{
-		string name = Util.MakeValidSQLAndFileName(Util.RemoveTildeAndColonAndDot(genericWin.EntrySelected));
+		spin_race_encoder_exercise_v_segment_size_cm_show_needed ();
+	}
+
+	List<Gtk.SpinButton> v_segments_size_cm_l;
+	private void spin_race_encoder_exercise_v_segment_size_cm_create_list ()
+	{
+		v_segments_size_cm_l = new List<Gtk.SpinButton>();
+
+		v_segments_size_cm_l.Add(spin_race_encoder_exercise_v_segment_size_cm_0);
+		v_segments_size_cm_l.Add(spin_race_encoder_exercise_v_segment_size_cm_1);
+		v_segments_size_cm_l.Add(spin_race_encoder_exercise_v_segment_size_cm_2);
+		v_segments_size_cm_l.Add(spin_race_encoder_exercise_v_segment_size_cm_3);
+		v_segments_size_cm_l.Add(spin_race_encoder_exercise_v_segment_size_cm_4);
+		v_segments_size_cm_l.Add(spin_race_encoder_exercise_v_segment_size_cm_5);
+		v_segments_size_cm_l.Add(spin_race_encoder_exercise_v_segment_size_cm_6);
+		v_segments_size_cm_l.Add(spin_race_encoder_exercise_v_segment_size_cm_7);
+		v_segments_size_cm_l.Add(spin_race_encoder_exercise_v_segment_size_cm_8);
+		v_segments_size_cm_l.Add(spin_race_encoder_exercise_v_segment_size_cm_9);
+		v_segments_size_cm_l.Add(spin_race_encoder_exercise_v_segment_size_cm_10);
+		v_segments_size_cm_l.Add(spin_race_encoder_exercise_v_segment_size_cm_11);
+		v_segments_size_cm_l.Add(spin_race_encoder_exercise_v_segment_size_cm_12);
+		v_segments_size_cm_l.Add(spin_race_encoder_exercise_v_segment_size_cm_13);
+		v_segments_size_cm_l.Add(spin_race_encoder_exercise_v_segment_size_cm_14);
+		v_segments_size_cm_l.Add(spin_race_encoder_exercise_v_segment_size_cm_15);
+		v_segments_size_cm_l.Add(spin_race_encoder_exercise_v_segment_size_cm_16);
+		v_segments_size_cm_l.Add(spin_race_encoder_exercise_v_segment_size_cm_17);
+		v_segments_size_cm_l.Add(spin_race_encoder_exercise_v_segment_size_cm_18);
+		v_segments_size_cm_l.Add(spin_race_encoder_exercise_v_segment_size_cm_19);
+		v_segments_size_cm_l.Add(spin_race_encoder_exercise_v_segment_size_cm_20);
+		v_segments_size_cm_l.Add(spin_race_encoder_exercise_v_segment_size_cm_21);
+		v_segments_size_cm_l.Add(spin_race_encoder_exercise_v_segment_size_cm_22);
+		v_segments_size_cm_l.Add(spin_race_encoder_exercise_v_segment_size_cm_23);
+		v_segments_size_cm_l.Add(spin_race_encoder_exercise_v_segment_size_cm_24);
+		v_segments_size_cm_l.Add(spin_race_encoder_exercise_v_segment_size_cm_25);
+		v_segments_size_cm_l.Add(spin_race_encoder_exercise_v_segment_size_cm_26);
+		v_segments_size_cm_l.Add(spin_race_encoder_exercise_v_segment_size_cm_27);
+		v_segments_size_cm_l.Add(spin_race_encoder_exercise_v_segment_size_cm_28);
+		v_segments_size_cm_l.Add(spin_race_encoder_exercise_v_segment_size_cm_29);
+		v_segments_size_cm_l.Add(spin_race_encoder_exercise_v_segment_size_cm_30);
+		v_segments_size_cm_l.Add(spin_race_encoder_exercise_v_segment_size_cm_31);
+		v_segments_size_cm_l.Add(spin_race_encoder_exercise_v_segment_size_cm_32);
+		v_segments_size_cm_l.Add(spin_race_encoder_exercise_v_segment_size_cm_33);
+		v_segments_size_cm_l.Add(spin_race_encoder_exercise_v_segment_size_cm_34);
+		v_segments_size_cm_l.Add(spin_race_encoder_exercise_v_segment_size_cm_35);
+		v_segments_size_cm_l.Add(spin_race_encoder_exercise_v_segment_size_cm_36);
+		v_segments_size_cm_l.Add(spin_race_encoder_exercise_v_segment_size_cm_37);
+		v_segments_size_cm_l.Add(spin_race_encoder_exercise_v_segment_size_cm_38);
+		v_segments_size_cm_l.Add(spin_race_encoder_exercise_v_segment_size_cm_39);
+	}
+
+	private void spin_race_encoder_exercise_v_segment_size_cm_reset_list ()
+	{
+		foreach(Gtk.SpinButton sb in v_segments_size_cm_l)
+			sb.Value = 100;
+	}
+
+	private void spin_race_encoder_exercise_v_segment_size_cm_show_needed ()
+	{
+		int toShow = Convert.ToInt32(spin_race_encoder_exercise_v_segments_num.Value);
+
+		int count = 0;
+		foreach(Gtk.SpinButton sb in v_segments_size_cm_l)
+		{
+			sb.Visible = (count < toShow);
+			count ++;
+		}
+	}
+
+	private bool run_encoder_exercise_do_add_or_edit (bool adding)
+	{
+		string name = Util.MakeValidSQLAndFileName(Util.RemoveTildeAndColonAndDot(entry_run_encoder_exercise_name.Text));
 		name = Util.RemoveChar(name, '"');
+		label_contacts_exercise_error.Text = "";
 
 		if(adding)
 			LogB.Information("run_encoder_exercise_do - Trying to insert: " + name);
@@ -1937,36 +2065,58 @@ public partial class ChronoJumpWindow
 
 		if(name == "")
 		{
-			genericWin.SetLabelError(Catalog.GetString("Error: Missing name of exercise."));
+			label_contacts_exercise_error.Text = Catalog.GetString("Error: Missing name of exercise.");
 			return false;
 		}
 		else if (adding && Sqlite.Exists(false, Constants.RunEncoderExerciseTable, name))
 		{
-			genericWin.SetLabelError(string.Format(Catalog.GetString(
-							"Error: An exercise named '{0}' already exists."), name));
+			label_contacts_exercise_error.Text = string.Format(Catalog.GetString(
+							"Error: An exercise named '{0}' already exists."), name);
 			return false;
 		}
 		else if (! adding) //if we are editing
 		{
 			//if we edit, check that this name does not exists (on other exercise, on current editing exercise is obviously fine)
 			int getIdOfThis = Sqlite.ExistsAndGetUniqueID(false, Constants.RunEncoderExerciseTable, name); //if not exists will be -1
-			if(getIdOfThis != -1 && getIdOfThis != genericWin.uniqueID)
+			if(getIdOfThis != -1 && getIdOfThis != getExerciseIDFromAnyCombo(combo_run_encoder_exercise, runEncoderComboExercisesString, false))
 			{
-				genericWin.SetLabelError(string.Format(Catalog.GetString(
-								"Error: An exercise named '{0}' already exists."), name));
+				label_contacts_exercise_error.Text = string.Format(Catalog.GetString(
+								"Error: An exercise named '{0}' already exists."), name);
 
 				return false;
 			}
 		}
 
+		int segmentCm = Convert.ToInt32(spin_race_encoder_exercise_f_segment_size_cm.Value);
+		List<int> segmentVariableCm = new List<int>();
+		if(! check_run_encoder_exercise_fixed_size.Active)
+		{
+			segmentCm = -1;
+
+			int i = 0;
+			foreach(Gtk.SpinButton sb in v_segments_size_cm_l)
+			{
+				if(i < spin_race_encoder_exercise_v_segments_num.Value)
+					segmentVariableCm.Add(Convert.ToInt32(sb.Value));
+				i ++;
+			}
+		}
+
 		if(adding)
-			SqliteRunEncoderExercise.Insert(false, -1, name,
-					genericWin.Entry2Selected, genericWin.SpinInt2Selected);
-		else {
-			RunEncoderExercise ex = new RunEncoderExercise(genericWin.uniqueID, name,
-					genericWin.Entry2Selected, genericWin.SpinInt2Selected);
+		{
+			RunEncoderExercise ex = new RunEncoderExercise (
+					-1, name, entry_run_encoder_exercise_description.Text,
+					segmentCm, segmentVariableCm, check_run_encoder_exercise_is_sprint.Active);
+			ex.InsertSQL (false);
+			currentRunEncoderExercise = ex;
+		} else {
+			RunEncoderExercise ex = new RunEncoderExercise(
+					getExerciseIDFromAnyCombo(combo_run_encoder_exercise, runEncoderComboExercisesString, false),
+					name, entry_run_encoder_exercise_description.Text,
+					segmentCm, segmentVariableCm, check_run_encoder_exercise_is_sprint.Active);
 
 			SqliteRunEncoderExercise.Update(false, ex);
+			currentRunEncoderExercise = ex;
 		}
 
 		fillRunEncoderExerciseCombo(name);
@@ -1984,8 +2134,8 @@ public partial class ChronoJumpWindow
 			return;
 		}
 
-		RunEncoderExercise ex = (RunEncoderExercise) SqliteRunEncoderExercise.Select (
-                                false, getExerciseIDFromAnyCombo(combo_run_encoder_exercise, runEncoderComboExercisesString, false), false)[0];
+		RunEncoderExercise ex = SqliteRunEncoderExercise.Select (
+                                false, getExerciseIDFromAnyCombo(combo_run_encoder_exercise, runEncoderComboExercisesString, false))[0];
 
 		LogB.Information("selected exercise: " + ex.ToString());
 
@@ -2091,35 +2241,96 @@ public partial class ChronoJumpWindow
 		if(radio_race_analyzer_capture_view_simple.Active)
 			return;
 
+		bool isSprint = false;
+		if(currentRunEncoderExercise != null && currentRunEncoderExercise.IsSprint)
+			isSprint = true;
+
+		TwoListsOfDoubles verticalLinesUs_2l = new TwoListsOfDoubles();
+		if(currentRunEncoderExercise != null && //currentRunEncoderExercise.SegmentCm > 0 &&
+				reCGSD != null && reCGSD.SegmentDistTime_2l != null)
+			verticalLinesUs_2l = reCGSD.SegmentDistTime_2l;
+
 		if(cairoGraphRaceAnalyzer_dt == null)
 			cairoGraphRaceAnalyzer_dt = new CairoGraphRaceAnalyzer(
 					drawingarea_race_analyzer_capture_position_time, "title",
-					Catalog.GetString("Distance"), "m", false);
+					Catalog.GetString("Distance"), "m",
+					isSprint, false,
+					verticalLinesUs_2l, true);
 
 		cairoGraphRaceAnalyzer_dt.DoSendingList (preferences.fontType.ToString(),
-				cairoGraphRaceAnalyzerPoints_dt_l, forceRedraw, CairoXY.PlotTypes.LINES);
+				cairoGraphRaceAnalyzerPoints_dt_l, triggerListRunEncoder,
+				forceRedraw, CairoXY.PlotTypes.LINES);
 	}
 	private void updateRaceAnalyzerCaptureSpeedTime(bool forceRedraw)
 	{
+		bool isSprint = false;
+		if(currentRunEncoderExercise != null && currentRunEncoderExercise.IsSprint)
+			isSprint = true;
+
+		TwoListsOfDoubles verticalLinesUs_2l = new TwoListsOfDoubles();
+		if(currentRunEncoderExercise != null && //currentRunEncoderExercise.SegmentCm > 0 &&
+				reCGSD != null && reCGSD.SegmentDistTime_2l != null)
+			verticalLinesUs_2l = reCGSD.SegmentDistTime_2l;
+
 		if(cairoGraphRaceAnalyzer_st == null)
 			cairoGraphRaceAnalyzer_st = new CairoGraphRaceAnalyzer(
 					drawingarea_race_analyzer_capture_speed_time, "title",
-					Catalog.GetString("Speed"), "m/s", true);
+					Catalog.GetString("Speed"), "m/s",
+					isSprint, true,
+					verticalLinesUs_2l, false);
 
 		cairoGraphRaceAnalyzer_st.DoSendingList (preferences.fontType.ToString(),
-				cairoGraphRaceAnalyzerPoints_st_l, forceRedraw, CairoXY.PlotTypes.LINES);
+				cairoGraphRaceAnalyzerPoints_st_l, triggerListRunEncoder,
+				forceRedraw, CairoXY.PlotTypes.LINES);
 	}
 	private void updateRaceAnalyzerCaptureAccelTime(bool forceRedraw)
 	{
 		if(radio_race_analyzer_capture_view_simple.Active)
 			return;
 
+		bool isSprint = false;
+		if(currentRunEncoderExercise != null && currentRunEncoderExercise.IsSprint)
+			isSprint = true;
+
+		TwoListsOfDoubles verticalLinesUs_2l = new TwoListsOfDoubles();
+		if(currentRunEncoderExercise != null && //currentRunEncoderExercise.SegmentCm > 0 &&
+				reCGSD != null && reCGSD.SegmentDistTime_2l != null)
+			verticalLinesUs_2l = reCGSD.SegmentDistTime_2l;
+
 		if(cairoGraphRaceAnalyzer_at == null)
 			cairoGraphRaceAnalyzer_at = new CairoGraphRaceAnalyzer(
 					drawingarea_race_analyzer_capture_accel_time, "title",
-					Catalog.GetString("Accel"), "m/s^2", false);
+					Catalog.GetString("Accel"), "m/s^2",
+					isSprint, false,
+					verticalLinesUs_2l, false);
 
 		cairoGraphRaceAnalyzer_at.DoSendingList (preferences.fontType.ToString(),
-				cairoGraphRaceAnalyzerPoints_at_l, forceRedraw, CairoXY.PlotTypes.LINES);
+				cairoGraphRaceAnalyzerPoints_at_l, triggerListRunEncoder,
+				forceRedraw, CairoXY.PlotTypes.LINES);
 	}
+
+	private void on_button_race_analyzer_capture_save_image_clicked (object o, EventArgs args)
+	{
+		checkFile(Constants.CheckFileOp.RUNENCODER_CAPTURE_SAVE_IMAGE);
+	}
+	private void on_button_run_encoder_capture_image_save_selected (string destination)
+	{
+		try {
+			Gdk.Pixbuf pixbuf = UtilGtk.PixbufFromVBox(vbox_race_analyzer_capture_graphs);
+			LogB.Information("Saving");
+			pixbuf.Save(destination,"png");
+		} catch {
+			string myString = string.Format(
+					Catalog.GetString("Cannot save file {0} "), destination);
+			new DialogMessage(Constants.MessageTypes.WARNING, myString);
+		}
+	}
+	private void on_overwrite_file_runencoder_capture_image_save_accepted(object o, EventArgs args)
+	{
+		on_button_run_encoder_capture_image_save_selected (exportFileName);
+
+		string myString = string.Format(Catalog.GetString("Saved to {0}"), exportFileName);
+		new DialogMessage(Constants.MessageTypes.INFO, myString);
+	}
+
 }
