@@ -28,7 +28,6 @@ using Mono.Unix;
 
 public partial class ChronoJumpWindow 
 {
-	[Widget] Gtk.Notebook notebook_run_encoder_analyze;
 	[Widget] Gtk.CheckButton check_run_encoder_analyze_accel;
 	[Widget] Gtk.CheckButton check_run_encoder_analyze_force;
 	[Widget] Gtk.CheckButton check_run_encoder_analyze_power;
@@ -60,10 +59,15 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.SpinButton spinbutton_run_encoder_export_image_height;
 	[Widget] Gtk.CheckButton check_run_encoder_export_instantaneous;
 	[Widget] Gtk.ProgressBar progressbar_run_encoder_export;
+	[Widget] Gtk.Label label_run_encoder_export_discarded;
 	[Widget] Gtk.Label label_run_encoder_export_result;
 	[Widget] Gtk.Button button_run_encoder_export_result_open;
 
+	[Widget] Gtk.Notebook notebook_run_encoder_analyze;
+	[Widget] Gtk.Notebook notebook_run_encoder_analyze_current_set;
+
 	private enum notebook_run_encoder_analyze_pages { CURRENTSET, CURRENTSESSION, OPTIONS }
+	private enum notebook_run_encoder_analyze_current_set_pages { GRAPH, TABLE, TRIGGERS }
 
 	private void createRunEncoderAnalyzeCombos ()
 	{
@@ -125,9 +129,16 @@ public partial class ChronoJumpWindow
 	}
 
 	private bool button_run_encoder_analyze_analyze_was_sensitive; //needed this temp variable
+	private int notebook_run_encoder_analyze_coming_page; //needed this temp variable
 	private void on_button_run_encoder_analyze_options_clicked (object o, EventArgs args)
 	{
+		//only show close_and_analyze button on current set tab
+		button_run_encoder_analyze_options_close_and_analyze.Visible =
+			(notebook_run_encoder_analyze.CurrentPage == Convert.ToInt32(notebook_run_encoder_analyze_pages.CURRENTSET));
+
+		notebook_run_encoder_analyze_coming_page = Convert.ToInt32(notebook_run_encoder_analyze.CurrentPage);
 		notebook_run_encoder_analyze.CurrentPage = Convert.ToInt32(notebook_run_encoder_analyze_pages.OPTIONS);
+
 		hbox_run_encoder_analyze_top_modes.Sensitive = false;
 		runEncoderButtonsSensitive(false);
 
@@ -173,7 +184,7 @@ public partial class ChronoJumpWindow
 
 		// 2 change sensitivity of widgets
 
-		notebook_run_encoder_analyze.CurrentPage = Convert.ToInt32(notebook_run_encoder_analyze_pages.CURRENTSET);
+		notebook_run_encoder_analyze.CurrentPage = notebook_run_encoder_analyze_coming_page;
 		runEncoderButtonsSensitive(true);
 		button_run_encoder_analyze_analyze.Sensitive = button_run_encoder_analyze_analyze_was_sensitive;
 	}
@@ -192,16 +203,40 @@ public partial class ChronoJumpWindow
 			return;
 		}
 
+		if(operatingSystem == UtilAll.OperatingSystems.MACOSX &&
+				! Util.FileExists(Constants.ROSX) )
+		{
+			showMacRInstallMessage ();
+			return;
+		}
+
+		if(! currentRunEncoderExercise.IsSprint)
+		{
+			new DialogMessage(Constants.MessageTypes.WARNING, "Currently you can only analyze sprint exercises.");
+			return;
+		}
+
 		if(lastRunEncoderFullPath != null && lastRunEncoderFullPath != "")
 			raceEncoderCopyToTempAndDoRGraph();
+
+		//move from triggers tab (if we are there) to graph tab
+		if(notebook_run_encoder_analyze_current_set.CurrentPage ==
+				Convert.ToInt32(notebook_run_encoder_analyze_current_set_pages.TRIGGERS))
+			notebook_run_encoder_analyze_current_set.CurrentPage =
+				Convert.ToInt32(notebook_run_encoder_analyze_current_set_pages.GRAPH);
+	}
+
+	private void on_button_raceAnalyzer_table_save_clicked (object o, EventArgs args)
+	{
+		checkFile(Constants.CheckFileOp.RUNENCODER_ANALYZE_SAVE_TABLE);
 	}
 
 	private void on_button_run_encoder_image_save_clicked (object o, EventArgs args)
 	{
-		checkFile(Constants.CheckFileOp.RUNENCODER_SAVE_IMAGE);
+		checkFile(Constants.CheckFileOp.RUNENCODER_ANALYZE_SAVE_IMAGE);
 	}
 
-	private void on_button_run_encoder_image_save_selected (string destination)
+	private void on_button_run_encoder_analyze_image_save_selected (string destination)
 	{
 		try {
 			File.Copy(UtilEncoder.GetSprintEncoderImage(), destination, true);
@@ -212,9 +247,9 @@ public partial class ChronoJumpWindow
 		}
 	}
 
-	private void on_overwrite_file_runencoder_image_save_accepted(object o, EventArgs args)
+	private void on_overwrite_file_runencoder_analyze_image_save_accepted(object o, EventArgs args)
 	{
-		on_button_run_encoder_image_save_selected (exportFileName);
+		on_button_run_encoder_analyze_image_save_selected (exportFileName);
 
 		string myString = string.Format(Catalog.GetString("Saved to {0}"), exportFileName);
 		new DialogMessage(Constants.MessageTypes.INFO, myString);
@@ -277,6 +312,7 @@ public partial class ChronoJumpWindow
 		hbox_run_encoder_export_width_height.Visible = check_run_encoder_export_images.Active;
 
 		//also hide the label and the open button
+		label_run_encoder_export_discarded.Text = "";
 		label_run_encoder_export_result.Text = "";
 		button_run_encoder_export_result_open.Visible = false;
 	}
@@ -287,6 +323,7 @@ public partial class ChronoJumpWindow
 		button_run_encoder_analyze_analyze.Visible = true;
 
 		notebook_run_encoder_analyze.CurrentPage = Convert.ToInt32(notebook_run_encoder_analyze_pages.CURRENTSET);
+		label_run_encoder_export_discarded.Text = "";
 		label_run_encoder_export_result.Text = "";
 		button_run_encoder_export_result_open.Visible = false;
 	}
@@ -301,6 +338,7 @@ public partial class ChronoJumpWindow
 			label_run_encoder_export_data.Text = "";
 
 		notebook_run_encoder_analyze.CurrentPage = Convert.ToInt32(notebook_run_encoder_analyze_pages.CURRENTSESSION);
+		label_run_encoder_export_discarded.Text = "";
 		label_run_encoder_export_result.Text = "";
 		button_run_encoder_export_result_open.Visible = false;
 	}
@@ -312,12 +350,20 @@ public partial class ChronoJumpWindow
 		label_run_encoder_export_data.Text = currentSession.Name;
 
 		notebook_run_encoder_analyze.CurrentPage = Convert.ToInt32(notebook_run_encoder_analyze_pages.CURRENTSESSION);
+		label_run_encoder_export_discarded.Text = "";
 		label_run_encoder_export_result.Text = "";
 		button_run_encoder_export_result_open.Visible = false;
 	}
 
 	private void on_button_run_encoder_export_not_set_clicked (object o, EventArgs args)
 	{
+		if(operatingSystem == UtilAll.OperatingSystems.MACOSX &&
+				! Util.FileExists(Constants.ROSX) )
+		{
+			showMacRInstallMessage ();
+			return;
+		}
+
 		// 1) check if all sessions
 		if(radio_run_encoder_analyze_individual_all_sessions.Active)
 		{
@@ -348,6 +394,7 @@ public partial class ChronoJumpWindow
 	RunEncoderExport runEncoderExport;
 	private void button_run_encoder_export_session (int personID, int sessionID)
 	{
+		label_run_encoder_export_discarded.Text = "";
 		label_run_encoder_export_result.Text = "";
 		button_run_encoder_export_result_open.Visible = false;
 		runEncoderButtonsSensitive(false);
@@ -374,6 +421,7 @@ public partial class ChronoJumpWindow
 		runEncoderExport = new RunEncoderExport (
 				notebook_run_encoder_export,
 				progressbar_run_encoder_export,
+				label_run_encoder_export_discarded,
 				label_run_encoder_export_result,
 				check_run_encoder_export_images.Active,
 				Convert.ToInt32(spinbutton_run_encoder_export_image_width.Value),
