@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2020   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2020-2021   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
@@ -27,13 +27,29 @@ using Mono.Unix;
 
 public partial class ChronoJumpWindow
 {
-	string app1s_fileDB;
-	string app1s_fileCopy;
+	//string app1s_fileDB;
+	string app1s_fileCopy; //contains chronojump_datetime
+	string app1s_parentCopy; //is the dir selected by app1s_fc, before adding chronojump_datetime,
+				//nice to store in SQL and reuse in next backups
 	Gtk.FileChooserDialog app1s_fc;
 	static UtilCopy app1s_uc;
 	private Thread app1s_threadBackup;
 
+	private enum notebook_session_backup_pages { BACKUP_DO, SCHEDULED_QUESTIONS, SCHEDULED_FEEDBACK, DELETE_OLD }
+
+	//if entered from more, cancel_close should go to more again
+	//but, if entered directly by scheduled, go to app1
+	private bool backup_cancel_close_show_more_notebook;
+
+	//user clicks on backup
 	private void on_button_db_backup_pre_clicked (object o, EventArgs args)
+	{
+		backup_cancel_close_show_more_notebook = true; //coming from more, so should go to more
+		label_backup_why.Visible = true; //user clicked on backup from more window. Show this label
+		db_backup_pre_2 ();
+	}
+
+	private void db_backup_pre_2 ()
 	{
 		if(! app1s_getDatabaseFile())
 		{
@@ -41,14 +57,116 @@ public partial class ChronoJumpWindow
 			return;
 		}
 
+		notebook_session_backup.Page = Convert.ToInt32(notebook_session_backup_pages.BACKUP_DO);
 		app1s_label_backup_destination.Text = "";
 		app1s_label_backup_progress.Text = "";
 		app1s_button_backup_select.Sensitive = true;
 		app1s_button_backup_start.Sensitive = false;
+		app1s_button_delete_old_incomplete.Visible = false;
 		app1s_button_backup_cancel_close.Sensitive = true;
 		app1s_label_backup_cancel_close.Text = Catalog.GetString("Cancel");
-	
+
 		app1s_notebook.CurrentPage = app1s_PAGE_BACKUP;
+
+		int sizeInKB = Util.GetFullDataSize (false);
+		app1s_label_backup_estimated_size.Text = string.Format(Catalog.GetString("Estimated size: {0} MB."),
+				UtilAll.DivideSafe(sizeInKB, 1000));
+	}
+
+	private bool shouldAskBackupScheduled ()
+	{
+		// 1) if next days is -1 (never ask again), do not show widget
+		if(preferences.backupScheduledNextDays < 0)
+			return false;
+
+		// 2) if never scheduled, need to show widget
+		if(preferences.backupScheduledCreatedDate == DateTime.MinValue)
+			return true;
+
+		// 3) if backup has to be done, show widget
+		// <0 means "This instance is earlier than value.". So if created date + nextDays is < than current date, need to do backup
+		if(preferences.backupScheduledCreatedDate.AddDays(preferences.backupScheduledNextDays).CompareTo(DateTime.Now) <= 0)
+			return true;
+
+		return false;
+	}
+
+	//scheduled backup on start
+	private void backupScheduledAsk ()
+	{
+		menus_sensitive_import_not_danger(false);
+		app1s_notebook_sup_entered_from = notebook_sup.CurrentPage;
+                notebook_sup.CurrentPage = Convert.ToInt32(notebook_sup_pages.SESSION);
+
+		notebook_session_backup.Page = Convert.ToInt32(notebook_session_backup_pages.SCHEDULED_QUESTIONS);
+
+		app1s_notebook.CurrentPage = app1s_PAGE_BACKUP;
+
+		app1s_button_backup_cancel_close.Visible = false;
+		//TODO: remember to show again after pressing any of the buttons
+	}
+
+	private void on_app1s_button_backup_scheduled_now_clicked (object o, EventArgs args)
+	{
+		app1s_button_backup_cancel_close.Visible = true;
+		label_backup_why.Visible = false; //do not show again label_backup_why
+
+		db_backup_pre_2 ();
+	}
+
+	private void on_app1s_button_backup_scheduled_remind_clicked (object o, EventArgs args)
+	{
+		/*
+		   There is a remind_next_time and not a remind_tomorrow, because tomorrow will be days = 1.
+		   But, next day after the backup will continue being days = 1, bothering the user again (everyday).
+		   Using next_time (meaning: next Chronojump start), nothing is changed on sqlite,
+		   message will appear next time, days will be always 30 by default or 60 or 90 if last time selected one of those.
+		 */
+
+		int days = 0;
+		if (o == (object) app1s_button_backup_scheduled_remind_next_time)
+			days = 0;
+		else if (o == (object) app1s_button_backup_scheduled_remind_30d)
+			days = 30;
+		else if (o == (object) app1s_button_backup_scheduled_remind_60d)
+			days = 60;
+		else if (o == (object) app1s_button_backup_scheduled_remind_90d)
+			days = 90;
+
+		string message = Catalog.GetString("You will be prompted for a backup the next time you start Chronojump.");
+		if(days > 0)
+			message = string.Format(Catalog.GetString("You will be prompted for a backup in {0} days."), days);
+
+		app1_backup_remind_or_never_do (days, message);
+	}
+
+	private void on_app1s_button_backup_scheduled_never_clicked (object o, EventArgs args)
+	{
+		app1_backup_remind_or_never_do (-1, Catalog.GetString("You will no longer be bothered with scheduled backups, but you can continue backing up by clicking on") +
+				" " + Catalog.GetString("Session") + " / " + Catalog.GetString("More") + ".");
+	}
+
+	private void app1_backup_remind_or_never_do (int days, string message)
+	{
+		if(days != 0) //aplly changes on never (-1) and on 30/60/90
+		{
+			// 1) Sqlite changes
+			Sqlite.Open(); // ---->
+
+			SqlitePreferences.Update(SqlitePreferences.BackupScheduledCreatedDateStr, UtilDate.ToSql(DateTime.Now), true);
+			SqlitePreferences.Update(SqlitePreferences.BackupScheduledNextDaysStr, days.ToString(), true);
+
+			Sqlite.Close(); // <----
+		}
+
+		// 2) gui changes
+		label_backup_why.Visible = false;
+		notebook_session_backup.Page = Convert.ToInt32(notebook_session_backup_pages.SCHEDULED_FEEDBACK);
+		app1s_label_remind_feedback.Text = message;
+
+		backup_cancel_close_show_more_notebook = false; //clicking on close should not show session more
+		app1s_label_backup_cancel_close.Text = Catalog.GetString("Close");
+		app1s_button_backup_cancel_close.Visible = true;
 	}
 
 	private bool app1s_getDatabaseFile ()
@@ -60,7 +178,7 @@ public partial class ChronoJumpWindow
 
 		System.IO.FileInfo file1 = new System.IO.FileInfo(databaseURL);
 		System.IO.FileInfo file2 = new System.IO.FileInfo(databaseTempURL);
-		app1s_fileDB = "";
+		//app1s_fileDB = "";
 
 		long length1 = 0;
 		if(file1.Exists)
@@ -71,10 +189,12 @@ public partial class ChronoJumpWindow
 
 		if(length1 == 0 && length2 == 0)
 			return false;
+		/*
 		else if(length1 > length2)
 			app1s_fileDB = databaseURL;
 		else
 			app1s_fileDB = databaseTempURL;
+			*/
 
 		return true;
 	}
@@ -85,11 +205,15 @@ public partial class ChronoJumpWindow
 				app1,
 				FileChooserAction.SelectFolder,
 				Catalog.GetString("Cancel"),ResponseType.Cancel,
-				Catalog.GetString("Copy"),ResponseType.Accept
+				Catalog.GetString("Select"),ResponseType.Accept
 				);
 
+		app1s_fc.SetCurrentFolder(preferences.lastBackupDir);
+
 		if (app1s_fc.Run() == (int)ResponseType.Accept)
 		{
+			app1s_parentCopy = app1s_fc.Filename;
+
 			//if multimedia_and_encoder, then copy the folder. If not checked, then copy only the db file
 			//if(check_backup_multimedia_and_encoder.Active)
 				app1s_fileCopy = app1s_fc.Filename + Path.DirectorySeparatorChar + "chronojump_" + UtilDate.ToFile();
@@ -163,6 +287,20 @@ public partial class ChronoJumpWindow
 			app1s_BackupPulseEnd();
 
 			LogB.ThreadEnded();
+
+			if (! app1s_copyRecursiveSuccess)
+				return false;
+
+			//update Sqlite backup vars (preferences not neede because will not be used until next boot)
+			Sqlite.Open(); // ---->
+
+			DateTime nowDT = DateTime.Now;
+			SqlitePreferences.Update(SqlitePreferences.LastBackupDirStr, app1s_parentCopy, true);
+			SqlitePreferences.Update(SqlitePreferences.LastBackupDatetimeStr, UtilDate.ToSql(nowDT), true);
+			SqlitePreferences.Update(SqlitePreferences.BackupScheduledCreatedDateStr, UtilDate.ToSql(nowDT), true);
+
+			Sqlite.Close(); // <----
+
 			return false;
 		}
 
@@ -187,9 +325,23 @@ public partial class ChronoJumpWindow
 		app1s_pulsebarBackupSecondDirs.Fraction = 1;
 		app1s_backup_doing_sensitive_start_end(false);
 		//app1s_fc.Hide ();
-		app1s_label_backup_progress.Text =
-			string.Format(Catalog.GetString("Copied in {0} ms"),
-					app1s_copyRecursiveElapsedMs);
+
+		if (app1s_copyRecursiveSuccess)
+			app1s_label_backup_progress.Text =
+				string.Format(Catalog.GetString("Copied in {0} ms."),
+						app1s_copyRecursiveElapsedMs);
+		else
+			app1s_label_backup_progress.Text =
+				Catalog.GetString("Failed, maybe the disk is full.");
+
+		// show button to delete old backups (if exists)
+		if(Directory.Exists (Util.GetBackupDirOld()))
+		{
+			int filesBackup, sizeInKBBackup;
+			Util.GetBackupsSize (out filesBackup, out sizeInKBBackup);
+			if(filesBackup > 0)
+				app1s_button_delete_old_incomplete.Visible = true;
+		}
 	}
 
 	private void app1s_backup_doing_sensitive_start_end(bool start)
@@ -239,19 +391,36 @@ public partial class ChronoJumpWindow
 		}
 	}
 
+	private void on_app1s_button_delete_old_incomplete_clicked (object o, EventArgs args)
+	{
+		label_backup_why.Visible = false; //do not show again label_backup_why
+		app1s_label_backup_cancel_close.Text = Catalog.GetString("Cancel");
+
+		notebook_session_backup.Page = Convert.ToInt32(notebook_session_backup_pages.DELETE_OLD);
+	}
+	private void on_app1s_button_old_backups_delete_do_clicked (object o, EventArgs args)
+	{
+		Directory.Delete(Util.GetBackupDirOld(), true);
+
+		app1s_button_old_backups_delete_do.Sensitive = false;
+		app1s_label_old_backups_delete_done.Visible = true;
+		app1s_label_backup_cancel_close.Text = Catalog.GetString("Close");
+	}
+
 	/*
 	 * deprecated since 1.6.0. Use backup method below
 	*/
 	static long app1s_copyRecursiveElapsedMs;
-	static int app1s_backupMainDirsDone;
+	static bool app1s_copyRecursiveSuccess;
+	//static int app1s_backupMainDirsDone;
 	private void app1s_copyRecursive()
 	{
 		app1s_copyRecursiveElapsedMs = 0;
 		Stopwatch sw = new Stopwatch();
 		sw.Start();
 
-		//Util.CopyFilesRecursively(new DirectoryInfo(Util.GetParentDir(false)), new DirectoryInfo(app1s_fileCopy), out app1s_backupMainDirsDone);
-		app1s_uc.CopyFilesRecursively(new DirectoryInfo(Util.GetParentDir(false)), new DirectoryInfo(app1s_fileCopy), 0);
+		app1s_copyRecursiveSuccess = app1s_uc.CopyFilesRecursively(
+				new DirectoryInfo(Util.GetParentDir(false)), new DirectoryInfo(app1s_fileCopy), 0);
 		sw.Stop();
 
 		app1s_copyRecursiveElapsedMs = sw.ElapsedMilliseconds;
@@ -310,6 +479,11 @@ public partial class ChronoJumpWindow
 
 	private void on_app1s_button_backup_cancel_or_close_clicked (object o, EventArgs args)
 	{
-		app1s_notebook.CurrentPage = app1s_PAGE_MODES;
+		if(backup_cancel_close_show_more_notebook)
+			app1s_notebook.CurrentPage = app1s_PAGE_MODES;
+		else {
+			menus_sensitive_import_not_danger(true);
+			notebook_supSetOldPage();
+		}
 	}
 }
