@@ -25,7 +25,7 @@ using Mono.Unix;
 
 public partial class ChronoJumpWindow
 {
-	[Widget] Gtk.Button button_edit_current_person;
+	//[Widget] Gtk.Button button_edit_current_person;
 	[Widget] Gtk.Button button_edit_current_person_h;
 	[Widget] Gtk.Button button_run_encoder_analyze_load;
 	[Widget] Gtk.Button button_encoder_exercise;
@@ -49,11 +49,7 @@ public partial class ChronoJumpWindow
 		string up = Catalog.GetString("Up");
 		string down = Catalog.GetString("Down");
 
-		//menu
-		radio_show_menu.TooltipText += " (Escape)";
-
 		//persons
-		button_edit_current_person.TooltipText += string.Format(" ({0}+p)", kCtrl);
 		button_edit_current_person_h.TooltipText += string.Format(" ({0}+p)", kCtrl);
 		button_persons_up.TooltipText += string.Format(" ({0}+{1})", kCtrl, up);
 		button_persons_down.TooltipText += string.Format(" ({0}+{1})", kCtrl, down);
