@@ -33,13 +33,13 @@ public class JumpsDjOptimalFallGraph : CairoXY
 	{
 		this.area = area;
 
-		initGraph(font);
+		initGraph(font, .8);
 
 		g.SetFontSize(16);
 		printText(area.Allocation.Width /2, area.Allocation.Height /2, 24, textHeight,
 				needToExecuteJumpsStr + " " + jumpType + ".", g, alignTypes.CENTER);
 
-		endGraphDisposing();
+		endGraphDisposing(g);
 	}
 
 	//regular constructor
@@ -75,7 +75,7 @@ public class JumpsDjOptimalFallGraph : CairoXY
 	public override void Do(string font)
 	{
 		LogB.Information("at JumpsDjOptimalFallGraph.Do");
-		initGraph(font);
+		initGraph(font, .8);
 
                 findPointMaximums(false);
                 findAbsoluteMaximums();
@@ -86,7 +86,7 @@ public class JumpsDjOptimalFallGraph : CairoXY
 		if(coefs.Length == 3)
 			plotPredictedLine(predictedLineTypes.PARABOLE, predictedLineCrossMargins.TOUCH);
 
-		plotRealPoints(false);
+		plotRealPoints(PlotTypes.POINTS);
 
 		if(coefs.Length == 3)
 		{
@@ -103,7 +103,7 @@ public class JumpsDjOptimalFallGraph : CairoXY
 		}
 		writeTitle();
 
-		endGraphDisposing();
+		endGraphDisposing(g);
 	}
 
 	protected override void writeTitle()
