@@ -27,8 +27,6 @@ using Cairo;
 
 public class JumpsRjFatigueGraph : CairoXY
 {
-	private JumpsRjFatigue.Statistic statistic;
-
 	private int divideIn;
 
 	//constructor when there are no points
@@ -88,12 +86,12 @@ public class JumpsRjFatigueGraph : CairoXY
 		paintGrid(gridTypes.VERTICALLINES, false);
 		paintAxis();
 
-		g.Color = red;
+		g.SetSourceColor(red);
 		plotPredictedLine(predictedLineTypes.STRAIGHT, predictedLineCrossMargins.TOUCH);
-		//g.Color = black;
-		g.Color = gray99;
+		//g.SetSourceColor(black);
+		g.SetSourceColor(gray99);
 		divideAndPlotAverage(divideIn);
-		g.Color = black;
+		g.SetSourceColor(black);
 
 		plotRealPoints(PlotTypes.LINES);
 
@@ -157,7 +155,7 @@ public class JumpsRjFatigueGraph : CairoXY
 		g.LineTo(xbp, yp + pointsRadius);
 
 		printText(
-				graphWidth - outerMargins,
+				graphWidth - outerMargin,
 				Convert.ToInt32(yp),
 				0, textHeight, Util.TrimDecimals(y, 2), g, alignTypes.CENTER);
 
