@@ -33,6 +33,7 @@ public class JumpsWeightFVProfileGraph : CairoXY
 	public double fvprofile90;
 	public bool needDevelopForce;
 	private int imbalance;
+	private double personWeight;
 
 	public enum ErrorAtStart { ALLOK, NEEDLEGPARAMS, BADLEGPARAMS, NEEDJUMPS, NEEDJUMPSX, F0ANDV0NOTPOSITIVE, F0NOTPOSITIVE, V0NOTPOSITIVE }
 	private ErrorAtStart errorMessage;
@@ -98,6 +99,7 @@ public class JumpsWeightFVProfileGraph : CairoXY
 		imbalance = jwp.Imbalance();
 		f0Opt = jwp.F0Opt;
 		v0Opt = jwp.V0Opt;
+		personWeight = jwp.PersonWeight;
 
 		LogB.Information(string.Format("pmaxRel: {0}", jwp.PmaxRel));
 		LogB.Information(string.Format("z: {0}", jwp.Z));
@@ -175,38 +177,45 @@ public class JumpsWeightFVProfileGraph : CairoXY
 
 	protected override void writeTitle()
 	{
-		int ypos = -8;
+		double ypos = -9;
 
-		writeTextAtRight(ypos++, title, true);
-		writeTextAtRight(ypos++, "FV Profile", false);
-		writeTextAtRight(ypos++, date, false);
+		writeTextAtRight(++ypos, title, true);
+		writeTextAtRight(++ypos, "FV Profile", false);
+		writeTextAtRight(++ypos, date, false);
+		ypos ++;
 
-		ypos++;
-		writeTextAtRight(ypos++, string.Format("F0: {0} N/Kg", Math.Round(f0Rel,2)), false);
-		writeTextAtRight(ypos++, string.Format("V0: {0} m/s", Math.Round(v0,2)), false);
-		writeTextAtRight(ypos++, string.Format("Pmax: {0} W", Math.Round(pmax,1)), false);
+		writeTextAtRight(++ypos, string.Format("F0: {0} N/Kg", Math.Round(f0Rel,2)), false);
+		writeTextAtRight(++ypos, string.Format("V0: {0} m/s", Math.Round(v0,2)), false);
+		writeTextAtRight(++ypos, string.Format("Pmax: {0} W", Math.Round(pmax,1)), false);
 
-		writeTextAtRight(ypos++, "Samozino & col. 2008-13:", false);
-		writeTextAtRight(ypos++, string.Format("- Profile (90º): {0} %", Math.Round(fvprofile90,0)), false);
-		writeTextAtRight(ypos++, string.Format("- Imbalance: {0} %", imbalance), false);
+		writeTextAtRight(++ypos, "Samozino & col. 2008-13:", false);
+		writeTextAtRight(ypos+=.5, string.Format("- Profile (90º): {0} %", Math.Round(fvprofile90,0)), false);
+		writeTextAtRight(ypos+=.5, string.Format("- Imbalance: {0} %", imbalance), false);
 
 		g.SetSourceColor(red);
 		if(needDevelopForce)
-			writeTextAtRight(ypos++, "- " + Catalog.GetString("Need to develop force"), false);
+			writeTextAtRight(ypos+=.5, "- " + Catalog.GetString("Need to develop force"), false);
 		else
-			writeTextAtRight(ypos++, "- " + Catalog.GetString("Need to develop speed"), false);
+			writeTextAtRight(ypos+=.5, "- " + Catalog.GetString("Need to develop speed"), false);
 		g.SetSourceRGB(0, 0, 0);
+
+		//The force developed during 1RM was approximately 11 ± 5 % lower than F0
+		double squat1RMPredict = (.89*f0)/9.81 - personWeight;
+		double squat1RMPredictDiff = (.94*f0)/9.81 - personWeight - squat1RMPredict;
+		writeTextAtRight(++ypos, "Rivière & col. 2017:", false);
+		writeTextAtRight(ypos+=.5, "- Squat 1RM prediction:", false);
+		writeTextAtRight(ypos+=.5, string.Format("  {0} \u00B1{1} Kg",
+					Util.TrimDecimals(squat1RMPredict, 1),
+					Util.TrimDecimals(squat1RMPredictDiff, 1)
+					), false);
 	}
 
 	protected override void writeSelectedValues(int line, PointF pClosest)
 	{
-		double lineVertSpacing = 1;
+		g.SelectFontFace(font, Cairo.FontSlant.Normal, Cairo.FontWeight.Normal);
+		g.SetFontSize(textHeight);
 
-		// first check if it fits at right, if does not fit reduce lineVertSpacing
-		if(Convert.ToInt32(graphHeight/2) + textHeight*2*(line+4) > graphHeight - outerMargin)
-		{
-			lineVertSpacing = .5;
-		}
+		double lineVertSpacing = .5 ;
 
 		g.SetSourceColor(bluePlots);
 		writeTextAtRight(line, "Selected:", false);
