@@ -65,6 +65,7 @@ public abstract class CairoXY : CairoGeneric
 	protected double maxX = 0;
 	protected double minY = 1000000;
 	protected double maxY = 0;
+	protected double xAtMaxY = 0; //raw, used on raceAnalyzer
 	double yAtMMaxY;
 	protected double absoluteMaxX;
 	protected double absoluteMaxY;
@@ -108,7 +109,7 @@ public abstract class CairoXY : CairoGeneric
 	public virtual void Do(string font)
 	{
 	}
-	public virtual void DoSendingList(string font, List<PointF> points_list, bool forceRedraw, PlotTypes plotType)
+	public virtual void DoSendingList(string font, List<PointF> points_list, TriggerList triggerList, bool forceRedraw, PlotTypes plotType)
 	{
 	}
 
@@ -188,7 +189,10 @@ public abstract class CairoXY : CairoGeneric
 			if(p.Y < minY)
 				minY = p.Y;
 			if(p.Y > maxY)
+			{
 				maxY = p.Y;
+				xAtMaxY = p.X; //used on raceAnalyzer
+			}
 		}
 
 		if (showFullGraph)
@@ -299,13 +303,16 @@ public abstract class CairoXY : CairoGeneric
 		g.LineTo(outerMargin, graphHeight - outerMargin);
 		g.LineTo(graphWidth - outerMargin, graphHeight - outerMargin);
 		g.Stroke ();
-		printText(2, Convert.ToInt32(outerMargin/2), 0, textHeight, getYAxisLabel(), g, alignTypes.LEFT);
+		printYAxisText();
 		printXAxisText();
 		g.Stroke ();
 		g.LineWidth = 2;
 	}
 
-	//this combined with paintVerticalGridLine is different on RaceAnalyzer
+	protected virtual void printYAxisText()
+	{
+		printText(2, Convert.ToInt32(outerMargin/2), 0, textHeight, getYAxisLabel(), g, alignTypes.LEFT);
+	}
 	protected virtual void printXAxisText()
 	{
 		printText(graphWidth - Convert.ToInt32(outerMargin/2), graphHeight - outerMargin, 0, textHeight, getXAxisLabel(), g, alignTypes.LEFT);
@@ -315,11 +322,11 @@ public abstract class CairoXY : CairoGeneric
 	{
 		return getAxisLabel(xVariable, xUnits);
 	}
-	private string getYAxisLabel()
+	protected string getYAxisLabel()
 	{
 		return getAxisLabel(yVariable, yUnits);
 	}
-	private string getAxisLabel(string variable, string units)
+	protected string getAxisLabel(string variable, string units)
 	{
 		if(units == "")
 			return variable;
@@ -604,6 +611,9 @@ public abstract class CairoXY : CairoGeneric
 
 	protected virtual void writeSelectedValues(int line, PointF pClosest)
 	{
+		g.SelectFontFace(font, Cairo.FontSlant.Normal, Cairo.FontWeight.Normal);
+		g.SetFontSize(textHeight);
+
 		g.SetSourceColor(bluePlots);
 		writeTextAtRight(line, Catalog.GetString("Selected") + ":", false);
 		g.SetSourceRGB(0, 0, 0);
