@@ -34,7 +34,6 @@ public class DialogMessage
 	[Widget] Gtk.Image image_help;
 	[Widget] Gtk.Image image_inspect;
 
-	[Widget] Gtk.HBox hbox_stiffness_formula;
 	[Widget] Gtk.Button button_go;
 	public bool Visible;
 	private string button_go_link = "";
@@ -55,12 +54,7 @@ public class DialogMessage
 	public DialogMessage (Constants.MessageTypes type, string message, string objectToShow)
 	{
 		initialize("", type, message, false);
-		if(objectToShow == "hbox_stiffness_formula")
-		{
-			hbox_stiffness_formula.Show();
-			UtilGtk.ContrastLabelsHBox (Config.ColorBackgroundIsDark, hbox_stiffness_formula);
-		}
-		else if(objectToShow == "button_go_r_mac")
+		if(objectToShow == "button_go_r_mac")
 		{
 			button_go_link = Constants.RmacDownload;
 			button_go.Show();
@@ -127,8 +121,24 @@ public class DialogMessage
 		else
 			scrolledwindow_by_software.SetPolicy(PolicyType.Never, PolicyType.Never);
 
-		label_message.Show();	
-		dialog_message.Show();	
+		label_message.Show();
+		dialog_message.Show();
+
+		if(UtilAll.GetOSEnum() == UtilAll.OperatingSystems.MACOSX)
+			GLib.Timeout.Add(200, new GLib.TimeoutHandler(resizeDialogForMac));
+	}
+
+	/*
+	   on some macs, the label is not shown correctly, seems not a problem of frame or scrollerwin
+	   after resizing a bit (by user) is shown correctly, so resize here.
+	   */
+	private bool resizeDialogForMac ()
+	{
+		dialog_message.SetSizeRequest(
+				dialog_message.SizeRequest().Width + 3,
+				dialog_message.SizeRequest().Height + 3);
+
+		return false;
 	}
 
 	public void on_button_go_clicked (object obj, EventArgs args)
