@@ -71,6 +71,7 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.HBox hbox_encoder_exercise_encoder;
 	[Widget] Gtk.Button button_encoder_exercise_edit;
 	[Widget] Gtk.Button button_encoder_exercise_add;
+	[Widget] Gtk.Button button_encoder_exercise_delete;
 
 	//encoder ...
 	[Widget] Gtk.Alignment alignment_check_encoder_networks_upload;
@@ -184,6 +185,7 @@ public partial class ChronoJumpWindow
 			//don't allow to edit exercises
 			button_encoder_exercise_edit.Visible = false;
 			button_encoder_exercise_add.Visible = false;
+			button_encoder_exercise_delete.Visible = false;
 
 			//on networks do not allow to change devices until preferences option is checked
 			viewport_chronopics.Sensitive = false;
@@ -985,8 +987,6 @@ public partial class ChronoJumpWindow
 				tasks = new TaskDeserialize().DeserializeTaskEncoder(tasksStr);
 		}
 
-		/*
-		TODO: disabled temporarily
 		//3) get exercises and insert if needed (only on encoder)
 		if(configChronojump.CompujumpStationMode == Constants.Modes.POWERGRAVITATORY ||
 				configChronojump.CompujumpStationMode == Constants.Modes.POWERINERTIAL)
@@ -1012,12 +1012,11 @@ public partial class ChronoJumpWindow
 				{
 					SqliteEncoder.InsertExercise(
 							false, exRemote.uniqueID, exRemote.name, exRemote.percentBodyWeight,
-							"", "", "", type); //ressitance, description, speed1RM, type (encoderGI)
+							"", "", Util.ConvertToPoint(exRemote.Speed1RM), type);
 					updateEncoderExercisesGui(exRemote.name);
 				}
 			}
 		}
-		*/
 
 		//4) get other stationsCount
 		List<StationCount> stationsCount = json.GetOtherStationsWithPendingTasks(currentPerson.UniqueID, configChronojump.CompujumpStationID);
