@@ -50,8 +50,11 @@ public class PersonAddModifyWindow
 	[Widget] Gtk.Image image_photo_preview;
 	[Widget] Gtk.Image image_photo_do;
 
-	[Widget] Gtk.Button button_add_photo_file;
-	[Widget] Gtk.Button button_take_photo_do;
+	[Widget] Gtk.Button button_delete_photo_file;
+	[Widget] Gtk.Image image_photo_delete;
+
+	//[Widget] Gtk.Button button_add_photo_file;
+	//[Widget] Gtk.Button button_take_photo_do;
 	[Widget] Gtk.HBox hbox_camera;
 	
 	[Widget] Gtk.Label label_date;
@@ -140,7 +143,7 @@ public class PersonAddModifyWindow
 	private string sex = Constants.M;
 	private double weightIniMetric;
 	int pDN;
-	Gtk.CheckButton app1_checkbutton_video_contacts;
+	//Gtk.CheckButton app1_checkbutton_video_contacts;
 	
 	private int serverUniqueID;
 
@@ -192,6 +195,9 @@ public class PersonAddModifyWindow
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_person_outline.png");
 		image_load_person.Pixbuf = pixbuf;
 
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "stock_delete.png");
+		image_photo_delete.Pixbuf = pixbuf;
+
 		image_photo_from_file.Pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_attachment.png");
 		image_photo_preview.Pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_photo_preview.png");
 		image_photo_do.Pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_photo_do.png");
@@ -212,7 +218,15 @@ public class PersonAddModifyWindow
 				pixbuf = new Pixbuf (tempFileName);
 				image_photo_mini.Pixbuf = pixbuf;
 			}
+
+			button_delete_photo_file.Sensitive = true;
 		}
+		else {
+			pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_no_photo.png");
+			image_photo_mini.Pixbuf = pixbuf;
+			button_delete_photo_file.Sensitive = false;
+		}
+
 		//show zoom button only if big image exists
 		string photoBigFile = Util.UserPhotoURL(false, currentPerson.UniqueID);
 		if(photoBigFile != "")
@@ -319,6 +333,19 @@ public class PersonAddModifyWindow
 			Util.FileDelete(file);
 	}
 
+	//user wants to delete his photo
+	private void deletePhoto (int uniqueID)
+	{
+		LogB.Information("deletePhoto: " + uniqueID.ToString());
+		string file = Util.UserPhotoURL(false, uniqueID); //default
+		if(file != "")
+			Util.FileDelete(file);
+
+		file  = Util.UserPhotoURL(true, uniqueID); //small
+		if(file != "")
+			Util.FileDelete(file);
+	}
+
 	void on_button_add_photo_file_clicked (object o, EventArgs args)
 	{
 		Gtk.FileChooserDialog fc=
@@ -380,7 +407,7 @@ public class PersonAddModifyWindow
 		button_zoom.Sensitive = true;
 	}
 
-	Gtk.Window capturerWindow;
+	//Gtk.Window capturerWindow;
 	Webcam webcam;
 	//CapturerBin capturer;
 	void on_button_take_photo_preview_camera_clicked (object o, EventArgs args)
@@ -428,59 +455,18 @@ public class PersonAddModifyWindow
 			if(miniSuccess)
 				showMiniPhoto(filenameMini);
 		}
-
+		button_delete_photo_file.Sensitive = true;
 	}
 
-	//libCesarplayer method, jpeg
-	private void on_snapshot_done(Pixbuf pixbuf)
+	private void on_button_delete_photo_file_clicked (object o, EventArgs args)
 	{
-		deleteOldPhotosIfAny(currentPerson.UniqueID);
-		string fileName = Path.Combine(Path.GetTempPath(), Constants.PhotoTemp +
-				Util.GetMultimediaExtension(Constants.MultimediaItems.PHOTO));
-		
-		pixbuf.Save(fileName,"jpeg");
-		
-		//on windows there are problem using the fileNames that are not on temp
-		if(!adding)
-			File.Copy(fileName, Util.GetPhotoFileName(false, currentPerson.UniqueID), true); //overwrite
+		deletePhoto (currentPerson.UniqueID);
 
-		button_zoom.Sensitive = true;
-	}
+		button_delete_photo_file.Sensitive = false;
 
-	//libCesarplayer method, jpeg
-	private void on_snapshot_mini_done(Pixbuf pixbuf)
-	{
-		deleteOldPhotosIfAny(currentPerson.UniqueID);
-		string tempSmallFileName = Path.Combine(Path.GetTempPath(), Constants.PhotoSmallTemp +
-				Util.GetMultimediaExtension(Constants.MultimediaItems.PHOTO));
-		
-		pixbuf.Save(tempSmallFileName,"jpeg");
-		
-		//on windows there are problem using the fileNames that are not on temp
-		if(!adding)
-			File.Copy(tempSmallFileName, Util.GetPhotoFileName(true, currentPerson.UniqueID), true); //overwrite
-		
-		/*
-		capturer.Close();
-		capturer.Dispose();
-		*/
-		capturerWindow.Hide();
-
-		person_win.Show();
-
-
-		string tempFileName = Path.Combine(Path.GetTempPath(), Constants.PhotoSmallTemp +
-			Util.GetMultimediaExtension(Constants.MultimediaItems.PHOTO));
-		if(!adding) {
-			//on windows there are problem using the fileNames that are not on temp
-			string fileName = Util.GetPhotoFileName(true, currentPerson.UniqueID);
-			File.Copy(fileName, tempFileName, true);
-		}
-		
-		if(File.Exists(tempFileName)) {
-			Pixbuf pixbuf2 = new Pixbuf (tempFileName); //from a file
-			image_photo_mini.Pixbuf = pixbuf2;
-		}
+		Pixbuf pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_no_photo.png");
+		image_photo_mini.Pixbuf = pixbuf;
+		button_zoom.Sensitive = false;
 	}
 
 	void on_entries_required_changed (object o, EventArgs args)
@@ -541,7 +527,7 @@ public class PersonAddModifyWindow
 	static public PersonAddModifyWindow Show (Gtk.Window parent, 
 			Session mySession, Person currentPerson, int pDN, 
 			//Gtk.CheckButton app1_checkbutton_video, bool showCapturePhoto,
-			Gtk.CheckButton app1_checkbutton_video_contacts,
+			//Gtk.CheckButton app1_checkbutton_video_contacts,
 			string videoDevice, string videoDevicePixelFormat, string videoDeviceResolution, string videoDeviceFramerate,
 			bool compujump, bool metric)
 	{
@@ -551,7 +537,7 @@ public class PersonAddModifyWindow
 		}
 
 		PersonAddModifyWindowBox.pDN = pDN;
-		PersonAddModifyWindowBox.app1_checkbutton_video_contacts = app1_checkbutton_video_contacts;
+		///PersonAddModifyWindowBox.app1_checkbutton_video_contacts = app1_checkbutton_video_contacts;
 		PersonAddModifyWindowBox.videoDevice = videoDevice;
 		PersonAddModifyWindowBox.videoDevicePixelFormat = videoDevicePixelFormat;
 		PersonAddModifyWindowBox.videoDeviceResolution = videoDeviceResolution;
