@@ -53,6 +53,7 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.SpinButton spinbutton_sprint_export_image_width;
 	[Widget] Gtk.SpinButton spinbutton_sprint_export_image_height;
 	[Widget] Gtk.ProgressBar progressbar_sprint_export;
+	[Widget] Gtk.Label label_sprint_export_discarded;
 	[Widget] Gtk.Label label_sprint_export_result;
 	[Widget] Gtk.Button button_sprint_export_result_open;
 
@@ -206,6 +207,13 @@ public partial class ChronoJumpWindow
 
 	private void on_button_sprint_clicked (object o, EventArgs args)
 	{
+		if(operatingSystem == UtilAll.OperatingSystems.MACOSX &&
+				! Util.FileExists(Constants.ROSX) )
+		{
+			showMacRInstallMessage ();
+			return;
+		}
+
 		if(! GetSelectedSprint(treeview_runs_interval_sprint))
 		{
 			new DialogMessage(Constants.MessageTypes.WARNING, Catalog.GetString("Error"));
@@ -297,6 +305,7 @@ public partial class ChronoJumpWindow
 		hbox_sprint_export_width_height.Visible = check_sprint_export_images.Active;
 
 		//also hide the label and the open button
+		label_sprint_export_discarded.Text = "";
 		label_sprint_export_result.Text = "";
 		button_sprint_export_result_open.Visible = false;
 	}
@@ -305,6 +314,7 @@ public partial class ChronoJumpWindow
 	{
 		notebook_sprint_analyze_top.CurrentPage = 0;
 
+		label_sprint_export_discarded.Text = "";
 		label_sprint_export_result.Text = "";
 		button_sprint_export_result_open.Visible = false;
 	}
@@ -318,6 +328,7 @@ public partial class ChronoJumpWindow
 		else
 			label_sprint_export_data.Text = "";
 
+		label_sprint_export_discarded.Text = "";
 		label_sprint_export_result.Text = "";
 		button_sprint_export_result_open.Visible = false;
 	}
@@ -328,13 +339,22 @@ public partial class ChronoJumpWindow
 
 		label_sprint_export_data.Text = currentSession.Name;
 
+		label_sprint_export_discarded.Text = "";
 		label_sprint_export_result.Text = "";
 		button_sprint_export_result_open.Visible = false;
 	}
 
 	private void on_button_sprint_export_not_set_clicked (object o, EventArgs args)
 	{
-		// 1) check if all sessions
+		// 1) avoid exporting to R on mac if R is not installed
+		if(operatingSystem == UtilAll.OperatingSystems.MACOSX &&
+				! Util.FileExists(Constants.ROSX) )
+		{
+			showMacRInstallMessage ();
+			return;
+		}
+
+		// 2) check if all sessions
 		if(radio_sprint_analyze_individual_all_sessions.Active)
 		{
 			if(currentPerson == null)
@@ -344,7 +364,7 @@ public partial class ChronoJumpWindow
 			return;
 		}
 
-		// 2) current session (individual or groupal)
+		// 3) current session (individual or groupal)
 		if(currentSession == null)
 			return;
 
@@ -367,6 +387,7 @@ public partial class ChronoJumpWindow
 		//continue based on: private void button_run_encoder_export_session (int personID)
 		//TODO: sensitive stuff (false)
 
+		label_sprint_export_discarded.Text = "";
 		label_sprint_export_result.Text = "";
 		button_sprint_export_result_open.Visible = false;
 
@@ -391,6 +412,7 @@ public partial class ChronoJumpWindow
 		sprintExport = new SprintExport(
 				notebook_sprint_export,
 				progressbar_sprint_export,
+				label_sprint_export_discarded,
 				label_sprint_export_result,
 				check_sprint_export_images.Active,
 				Convert.ToInt32(spinbutton_sprint_export_image_width.Value),
