@@ -36,6 +36,7 @@ public class Person {
 	private string future1; 	//rfid
 	private string future2; 	//club ID, is an integer
 	private int serverUniqueID; //not on server
+	private string linkServerImage;
 
 	public Person() {
 	}
@@ -46,7 +47,7 @@ public class Person {
 	}
 
 	//coming from compujump server
-	public Person(bool insertPerson, int uniqueID, string name, string rfid) //TODO:, string clubID)
+	public Person(bool insertPerson, int uniqueID, string name, string rfid, string image) //TODO:, string clubID)
 	{
 		this.uniqueID = uniqueID;
 		this.name = name;
@@ -58,6 +59,7 @@ public class Person {
 		this.future1 = rfid;
 		//TODO: this.future2 = clubID;
 		this.serverUniqueID = Constants.ServerUndefinedID;
+		this.linkServerImage = image;
 
 		/*
 		 * Before insertion check that uniqueID exists locally
@@ -66,14 +68,15 @@ public class Person {
 		if(insertPerson)
 			SqlitePerson.Insert(false,
 					uniqueID.ToString(), name, sex, dateBorn, race, countryID,
-					description, future1, future2, serverUniqueID);
+					description, future1, future2, serverUniqueID, linkServerImage);
 	}
 
 	//suitable when we load a person from the database for being the current Person
 	//we know uniqueID
 	//used also in class PersonSessionTransaction where we define the uniqueID 
 	public Person(int uniqueID, string name, string sex, DateTime dateBorn, 
-			int race, int countryID, string description, string future1, string future2, int serverUniqueID)
+			int race, int countryID, string description,
+			string future1, string future2, int serverUniqueID, string linkServerImage)
 	{
 		//needed by the return of gui/personAddModifyWindow
 		name = Util.RemoveTildeAndColon(name);
@@ -89,13 +92,14 @@ public class Person {
 		this.future1 = future1;
 		this.future2 = future2;
 		this.serverUniqueID = serverUniqueID; //remember don't do this on server
+		this.linkServerImage = linkServerImage;
 	}
 
 	//typical constructor
 	//used when we create new person 
 	//we don't know uniqueID
 	public Person(string name, string sex, DateTime dateBorn, int race, int countryID, string description,
-			string future1, string future2, int serverUniqueID, bool dbconOpened)
+			string future1, string future2, int serverUniqueID, string linkServerImage, bool dbconOpened)
 	{
 		name = Util.RemoveTildeAndColon(name);
 		description = Util.RemoveTildeAndColon(description);
@@ -109,6 +113,7 @@ public class Person {
 		this.future1 = future1;
 		this.future2 = future2;
 		this.serverUniqueID = serverUniqueID; //remember don't do this on server
+		this.linkServerImage = linkServerImage;
 
 		//insert in the person table
 		//when insert as person we don't know uniqueID
@@ -124,7 +129,7 @@ public class Person {
 	public int InsertAtDB (bool dbconOpened, string tableName) {
 		int myID = SqlitePerson.Insert(dbconOpened,  
 				uniqueID.ToString(), name, sex, dateBorn, race, countryID,
-				description, future1, future2, serverUniqueID);
+				description, future1, future2, serverUniqueID, linkServerImage);
 		return myID;
 	}
 	
@@ -150,7 +155,7 @@ public class Person {
 		return uniqueID.ToString() + ", '"  + name + "', '" + sex + "', '" + 
 			UtilDate.ToSql(dateBorn) + "', " + race + ", " + countryID + ", '" +
 			description + "', '" + future1 + "', '" + future2 + "', " +
-			serverUniqueID;
+			serverUniqueID + ", '" + linkServerImage + "'";
 	}
 	
 	
@@ -213,6 +218,10 @@ public class Person {
 		set { serverUniqueID = value; }
 	}
 
+	public string LinkServerImage {
+		get { return linkServerImage; }
+	}
+
 	public int UniqueID {
 		get { return uniqueID; }
 		set { uniqueID = value; }
