@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2018-2020   Xavier de Blas <xaviblas@gmail.com>
+ *  Copyright (C) 2018-2022   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
@@ -269,6 +269,13 @@ public class RunEncoder
 //get speed, total distance, ...
 public class RunEncoderCaptureGetSpeedAndDisplacement
 {
+	//to calcule the vertical lines on pos/time, speed/time, accel/time
+	//it is calculated once and used on all
+	private int segmentCm;
+	private List<int> segmentVariableCm; //if segmentCm == -1 then this is used
+	private int segmentVariableCmDistAccumulated;
+	private TwoListsOfDoubles segmentDistTime_2l;
+
 	private int encoderDisplacement;
 	private int time;
 	private int force;
@@ -278,10 +285,15 @@ public class RunEncoderCaptureGetSpeedAndDisplacement
 
 	private double runEncoderCaptureSpeed;
 	private double runEncoderCaptureSpeedMax;
-	private double runEncoderCaptureDistance;
+	private double runEncoderCaptureDistance; //m
 
-	public RunEncoderCaptureGetSpeedAndDisplacement()
+	public RunEncoderCaptureGetSpeedAndDisplacement(int segmentCm, List<int> segmentVariableCm)
 	{
+		this.segmentCm = segmentCm;
+		this.segmentVariableCm = segmentVariableCm;
+		segmentVariableCmDistAccumulated = 0;
+
+		segmentDistTime_2l = new TwoListsOfDoubles();
 		timePre = 0;
 	}
 
@@ -320,17 +332,42 @@ public class RunEncoderCaptureGetSpeedAndDisplacement
 					runEncoderCaptureSpeedMax = runEncoderCaptureSpeed;
 
 				runEncoderCaptureDistance += runEncoderCaptureDistanceAtThisSample;
+
+				if(segmentCm > 0)
+					updateSegmentDistTimeFixed ();
+				else if(segmentVariableCm.Count > 0)
+					updateSegmentDistTimeVariable ();
+
 				hasCalculed = true;
 			}
 			timePre = time;
 		}
 		return hasCalculed;
 	}
+	private void updateSegmentDistTimeFixed () //m
+	{
+		if(runEncoderCaptureDistance >= (segmentCm/100.0) * (segmentDistTime_2l.Count() +1))
+			segmentDistTime_2l.Add((segmentCm/100.0) * (segmentDistTime_2l.Count() +1), time);
+		//note this is not very precise because time can be a bit later than the selected dist
+	}
+	private void updateSegmentDistTimeVariable () //cm
+	{
+		//care of overflow
+		if(segmentDistTime_2l.Count() >= segmentVariableCm.Count)
+			return;
+
+		double distToBeat = (segmentVariableCm[segmentDistTime_2l.Count()] + segmentVariableCmDistAccumulated) / 100.0; //cm -> m
+		if(runEncoderCaptureDistance >= distToBeat)
+		{
+			segmentVariableCmDistAccumulated += segmentVariableCm[segmentDistTime_2l.Count()];
+			segmentDistTime_2l.Add(distToBeat, time);
+		}
+	}
 
 	public int EncoderDisplacement {
 		get { return encoderDisplacement; }
 	}
-	public int Time {
+	public int Time { //microseconds
 		get { return time; }
 	}
 	public int Force {
@@ -350,6 +387,9 @@ public class RunEncoderCaptureGetSpeedAndDisplacement
 	public double RunEncoderCaptureDistance {
 		get { return runEncoderCaptureDistance; }
 	}
+	public TwoListsOfDoubles SegmentDistTime_2l {
+		get { return segmentDistTime_2l; }
+	}
 }
 
 public class RunEncoderExercise
@@ -357,8 +397,10 @@ public class RunEncoderExercise
 	private int uniqueID;
 	private string name;
 	private string description;
-	private int segmentMeters;
-	public static int SegmentMetersDefault = 5;
+	private int segmentCm;
+	public static int SegmentCmDefault = 500;
+	private List<int> segmentVariableCm; //if segmentCm == -1 then this is used
+	private bool isSprint;
 
 	public RunEncoderExercise()
 	{
@@ -369,17 +411,37 @@ public class RunEncoderExercise
 		this.name = name;
 	}
 
-	public RunEncoderExercise(int uniqueID, string name, string description, int segmentMeters)
+	public RunEncoderExercise(int uniqueID, string name, string description, int segmentCm, List<int> segmentVariableCm, bool isSprint)
 	{
 		this.uniqueID = uniqueID;
 		this.name = name;
 		this.description = description;
-		this.segmentMeters = segmentMeters;
+		this.segmentCm = segmentCm;
+		this.segmentVariableCm = segmentVariableCm;
+		this.isSprint = isSprint;
 	}
 
 	public override string ToString()
 	{
-		return string.Format("{0}:{1}:{2}:{3}", uniqueID, name, description, segmentMeters);
+		return string.Format("{0}:{1}:{2}:{3}:{4}:{5}",
+				uniqueID, name, description, segmentCm,
+				Util.ListIntToSQLString (segmentVariableCm, ";"), isSprint);
+	}
+
+	public void InsertSQL (bool dbconOpened)
+	{
+		SqliteRunEncoderExercise.Insert(dbconOpened, toSQLInsertString());
+	}
+
+	private string toSQLInsertString()
+	{
+		string uniqueIDStr = "NULL";
+		if(uniqueID != -1)
+			uniqueIDStr = uniqueID.ToString();
+
+		return
+			"(" + uniqueIDStr + ", \"" + name + "\", \"" + description + "\", " +
+			segmentCm + ", \"" + SegmentVariableCmToSQL + "\", " + Util.BoolToInt(isSprint) + ")";
 	}
 
 	public int UniqueID
@@ -394,9 +456,30 @@ public class RunEncoderExercise
 	{
 		get { return description; }
 	}
-	public int SegmentMeters
+	public int SegmentCm
 	{
-		get { return segmentMeters; }
+		get { return segmentCm; }
+		set { segmentCm = value; }
+	}
+	public List<int> SegmentVariableCm
+	{
+		get { return segmentVariableCm; }
+	}
+	public string SegmentVariableCmToSQL
+	{
+		get { return Util.ListIntToSQLString (segmentVariableCm, ";"); }
+	}
+	//same as above but return -1 if empty
+	public string SegmentVariableCmToR (string sep)
+	{
+		string str = Util.ListIntToSQLString (segmentVariableCm, sep);
+		if(str == "")
+			str = "-1";
+		return str;
+	}
+	public bool IsSprint
+	{
+		get { return isSprint; }
 	}
 }
 
@@ -514,7 +597,7 @@ public class RunEncoderGraphExport
 	private RunEncoder.Devices device;
 	private double tempC;
 	private int testLength;
-	private RunEncoderExercise rex;
+	private RunEncoderExercise exercise;
 	private string title;
 	private string datetime;
 	private TriggerList triggerList;
@@ -526,7 +609,7 @@ public class RunEncoderGraphExport
 			double mass, double personHeight,
 			RunEncoder.Devices device,
 			double tempC, int testLength,
-			RunEncoderExercise rex, string title, string datetime,
+			RunEncoderExercise exercise, string title, string datetime,
 			TriggerList triggerList,
 			string comments)
 	{
@@ -537,7 +620,7 @@ public class RunEncoderGraphExport
 		this.device = device;
 		this.tempC = tempC;
 		this.testLength = testLength;
-		this.rex = rex;
+		this.exercise = exercise;
 		this.title = title;
 		this.datetime = datetime;
 		this.comments = comments;
@@ -550,18 +633,29 @@ public class RunEncoderGraphExport
 		if(isWindows)
 			url = url.Replace("\\","/");
 
+		string segmentM = "-1"; //variable segments
+		string segmentVariableCm = "-1"; //fixed segments
+		if(exercise.SegmentCm > 0)
+			segmentM = Util.ConvertToPoint(exercise.SegmentCm / 100.0); //fixed segment
+		else
+		{
+			//it is a row separated by ; so we need , here
+			segmentVariableCm = exercise.SegmentVariableCmToR(",");
+		}
+
 		return url + ";" +
 			Util.ConvertToPoint(mass) + ";" +
 			Util.ConvertToPoint(personHeight / 100.0) + ";" + //in meters
 			device.ToString() + ";" +
 			Util.ConvertToPoint(tempC) + ";" +
 			testLength.ToString() + ";" +
-			rex.SegmentMeters.ToString() + ";" +
+			segmentM + ";" + //fixed segments (m)
+			segmentVariableCm + ";" + //variable segments (cm)
 			title + ";" +
 			datetime + ";" +
 			printTriggers(TriggerList.Type3.ON) + ";" +
 			printTriggers(TriggerList.Type3.OFF) + ";" +
-			Util.RemoveChar(comments, ';');  //TODO: check this really removes
+			Util.RemoveNewLine(Util.RemoveChar(comments, ';'), true);
 	}
 
 	private string printTriggers(TriggerList.Type3 type3)
@@ -572,9 +666,15 @@ public class RunEncoderGraphExport
 	public static string PrintCSVHeaderOnExport()
 	{
 		return "fullURL;mass;personHeight;device;tempC;testLength;" +
-			"splitLength;" + //segmentMeters on C#, splitLength on R
+			"splitLength;" + //segmentCm on C#, splitLength on R
+			"splitVariableCm;" +
 			"title;datetime;triggersOn;triggersOff;comments";
 	}
+
+	public RunEncoderExercise Exercise
+	{
+		get { return exercise; }
+	}
 }
 
 public class RunEncoderGraph
@@ -695,6 +795,16 @@ public class RunEncoderGraph
 		System.Globalization.NumberFormatInfo localeInfo = new System.Globalization.NumberFormatInfo();
 		localeInfo = System.Globalization.NumberFormatInfo.CurrentInfo;
 
+		string segmentM = "-1"; //variable segments
+		string segmentVariableCm = "-1"; //fixed segments
+		if(singleOrMultiple) //only on single
+		{
+			if(rex.SegmentCm > 0)
+				segmentM = Util.ConvertToPoint(rex.SegmentCm / 100.0); //fixed segment
+			else
+				segmentVariableCm = rex.SegmentVariableCmToR(";");
+		}
+
 		string scriptOptions =
 			"#scriptsPath\n" + 		UtilEncoder.GetScriptsPath() + "\n" +
 			"#filename\n" + 		RunEncoder.GetCSVFileName() + "\n" +	//unused on multiple
@@ -706,7 +816,8 @@ public class RunEncoderGraph
 			"#graphWidth\n" + 		graphWidth.ToString() + "\n" +
 			"#graphHeight\n" + 		graphHeight.ToString() + "\n" +
 			"#device\n" + 			device.ToString() + "\n" + //unused on multiple
-			"#segmentMeters\n" + 		rex.SegmentMeters + "\n" + //unused on multiple
+			"#segmentM\n" + 		segmentM + "\n" + 		//unused on multiple
+			"#segmentVariableCm\n" + 	segmentVariableCm + "\n" + 		//unused on multiple
 			"#title\n" + 			title + "\n" + 		//unused on multiple
 			"#datetime\n" + 		datetime + "\n" + 	//unused on multiple
 			"#startAccel\n" + 		Util.ConvertToPoint(startAccel) + "\n" +
