@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 
@@ -32,7 +32,7 @@ using Mono.Unix;
 
 class SqliteCountry : Sqlite
 {
-	protected internal static void createTable()
+	protected internal static new void createTable()
 	 {
 		dbcmd.CommandText = 
 			"CREATE TABLE " + Constants.CountryTable + " ( " +
