@@ -646,4 +646,29 @@ finishForeach:
 		Sqlite.Close();
 	}
 
+	//used on compujump
+	public static void UpdateName (int uniqueID, string name)
+	{
+		Sqlite.Open();
+		dbcmd.CommandText = "UPDATE " + Constants.PersonTable +
+			" SET name = \"" + name +
+			"\" WHERE uniqueID = " + uniqueID;
+
+		LogB.SQL(dbcmd.CommandText.ToString());
+		dbcmd.ExecuteNonQuery();
+		Sqlite.Close();
+	}
+
+	//used on compujump
+	public static void UpdateRFID (int uniqueID, string rfid)
+	{
+		Sqlite.Open();
+		dbcmd.CommandText = "UPDATE " + Constants.PersonTable +
+			" SET future1 = \"" + rfid +
+			"\" WHERE uniqueID = " + uniqueID;
+
+		LogB.SQL(dbcmd.CommandText.ToString());
+		dbcmd.ExecuteNonQuery();
+		Sqlite.Close();
+	}
 }
