@@ -36,6 +36,12 @@ class SqlitePreferences : Sqlite
 	public const string RestTimeMinutes = "restTimeMinutes";
 	public const string RestTimeSeconds = "restTimeSeconds";
 
+	//backup (scheduled or not)
+	public const string LastBackupDirStr = "lastBackupDir";
+	public const string LastBackupDatetimeStr = "lastBackupDatetime"; //merely informational
+	public const string BackupScheduledCreatedDateStr = "backupScheduledCreatedDate"; //when was scheduled (not when is the backup)
+	public const string BackupScheduledNextDaysStr = "backupScheduledNextDays"; // days to the backup (-1 is no scheduled backup and never ask again, 30/60/90 is 30/60/90 days)
+
 	//person (appearance)
 	public const string PersonSelectWinImages = "personSelectWinImages";
 
@@ -48,12 +54,15 @@ class SqlitePreferences : Sqlite
 	public const string SocialNetworkDatetime = "socialNetworkDatetime"; //"": not answered, -1: should be sent when there's network (after a ping)
 
 	//contacts
+	public const string ContactsCaptureDisplayStr = "contactsCaptureDisplay";
+	public const string RunEncoderCaptureDisplaySimple = "runEncoderCaptureDisplaySimple";
 	public const string JumpsFVProfileOnlyBestInWeight = "jumpsFVProfileOnlyBestInWeight";
 	public const string JumpsFVProfileShowFullGraph = "jumpsFVProfileShowFullGraph";
 	public const string JumpsEvolutionOnlyBestInSession = "jumpsEvolutionOnlyBestInSession";
 
 	public const string RunsEvolutionOnlyBestInSession = "runsEvolutionOnlyBestInSession";
 	public const string RunsEvolutionShowTime = "runsEvolutionShowTime";
+	public const string ShowJumpRSI = "showJumpRSI";
 
 	//encoder
 	public const string EncoderCaptureInfinite = "encoderCaptureInfinite";
@@ -167,7 +176,7 @@ class SqlitePreferences : Sqlite
 				//appearance
 				Insert ("maximized", Preferences.MaximizedTypes.NO.ToString(), dbcmdTr);
 				Insert ("personWinHide", "False", dbcmdTr);
-				Insert ("personPhoto", "True", dbcmdTr);
+				Insert ("personPhoto", "False", dbcmdTr);
 				Insert (PersonSelectWinImages, "True", dbcmdTr);
 				Insert (MenuType, Preferences.MenuTypes.ALL.ToString(), dbcmdTr);
 
@@ -185,12 +194,23 @@ class SqlitePreferences : Sqlite
 				Insert (RestTimeSeconds, "0", dbcmdTr);
 				Insert (UnitsStr, Preferences.UnitsEnum.METRIC.ToString(), dbcmdTr);
 				Insert (EncoderCaptureInfinite, "False", dbcmdTr);
-				Insert ("encoderCaptureShowOnlyBars", "True", dbcmdTr);
+
+				//backup
+				Insert (LastBackupDirStr, "", dbcmdTr);
+				Insert (LastBackupDatetimeStr, UtilDate.ToSql(DateTime.MinValue), dbcmdTr);
+				Insert (BackupScheduledCreatedDateStr, UtilDate.ToSql(DateTime.MinValue), dbcmdTr);
+				Insert (BackupScheduledNextDaysStr, "30", dbcmdTr);
+
+				Insert(ContactsCaptureDisplayStr, new ContactsCaptureDisplay(false, true).GetInt.ToString(), dbcmdTr);
+				Insert ("encoderCaptureShowOnlyBars", new EncoderCaptureDisplay(false, false, true).GetInt.ToString(), dbcmdTr);
+				Insert(RunEncoderCaptureDisplaySimple, "True", dbcmdTr);
+
 				Insert ("encoderCaptureShowNRepetitions", "-1", dbcmdTr);
 				Insert ("digitsNumber", "3", dbcmdTr);
 				Insert ("showPower", "True", dbcmdTr);
 				Insert ("showStiffness", "True", dbcmdTr);
 				Insert ("showInitialSpeed", "True", dbcmdTr);
+				Insert (ShowJumpRSI, "True", dbcmdTr);
 				Insert ("showAngle", "False", dbcmdTr); //for treeviewjumps
 				Insert ("showQIndex", "False", dbcmdTr); //for treeviewJumps
 				Insert ("showDjIndex", "False", dbcmdTr); //for treeviewJumps
@@ -293,7 +313,7 @@ class SqlitePreferences : Sqlite
 
 				//encoderRhythm
 				EncoderRhythm er = new EncoderRhythm();
-				Insert (EncoderRhythmActiveStr, er.Active.ToString(), dbcmdTr);
+				Insert (EncoderRhythmActiveStr, er.ActiveRhythm.ToString(), dbcmdTr);
 				Insert (EncoderRhythmRepsOrPhasesStr, er.RepsOrPhases.ToString(), dbcmdTr);
 				Insert (EncoderRhythmRepSecondsStr, Util.ConvertToPoint(er.RepSeconds), dbcmdTr);
 				Insert (EncoderRhythmEccSecondsStr, Util.ConvertToPoint(er.EccSeconds), dbcmdTr);
@@ -374,7 +394,7 @@ class SqlitePreferences : Sqlite
 				Insert (LoadLastSessionAtStart, "True", dbcmdTr);
 				Insert (LastSessionID, "-1", dbcmdTr);
 				Insert (LoadLastModeAtStart, "True", dbcmdTr);
-				Insert (LastMode, Constants.Menuitem_modes.UNDEFINED.ToString(), dbcmdTr);
+				Insert (LastMode, Constants.Modes.UNDEFINED.ToString(), dbcmdTr);
 				Insert (SessionLoadDisplay, "0", dbcmdTr);
 
 				//export
@@ -515,6 +535,17 @@ class SqlitePreferences : Sqlite
 				else
 					preferences.restTimeSeconds = 0;
 			}
+
+			//backup
+			else if(reader[0].ToString() == LastBackupDirStr)
+				preferences.lastBackupDir = reader[1].ToString();
+			else if(reader[0].ToString() == LastBackupDatetimeStr)
+				preferences.lastBackupDatetime = UtilDate.FromSql(reader[1].ToString());
+			else if(reader[0].ToString() == BackupScheduledCreatedDateStr)
+				preferences.backupScheduledCreatedDate = UtilDate.FromSql(reader[1].ToString());
+			else if(reader[0].ToString() == BackupScheduledNextDaysStr)
+				preferences.backupScheduledNextDays = Convert.ToInt32(reader[1].ToString());
+
 			else if(reader[0].ToString() == NewsLanguageEs )
 				preferences.newsLanguageEs = reader[1].ToString() == "True"; //bool
 			else if(reader[0].ToString() == ClientNewsDatetime )
@@ -528,8 +559,16 @@ class SqlitePreferences : Sqlite
 					Enum.Parse(typeof(Preferences.UnitsEnum), reader[1].ToString());
 			else if(reader[0].ToString() == EncoderCaptureInfinite)
 				preferences.encoderCaptureInfinite = reader[1].ToString() == "True";
+			else if(reader[0].ToString() == ContactsCaptureDisplayStr)
+			{
+				preferences.contactsCaptureDisplay = new ContactsCaptureDisplay(Convert.ToInt32(reader[1].ToString()));
+				preferences.contactsCaptureDisplayStored = preferences.contactsCaptureDisplay;
+			}
 			else if(reader[0].ToString() == "encoderCaptureShowOnlyBars")
-				preferences.encoderCaptureShowOnlyBars = reader[1].ToString() == "True";
+			{
+				preferences.encoderCaptureShowOnlyBars = new EncoderCaptureDisplay(Convert.ToInt32(reader[1].ToString()));
+				preferences.encoderCaptureShowOnlyBarsStored = preferences.encoderCaptureShowOnlyBars;
+			}
 			else if(reader[0].ToString() == "encoderCaptureShowNRepetitions")
 				preferences.encoderCaptureShowNRepetitions = Convert.ToInt32(reader[1].ToString());
 			else if(reader[0].ToString() == "showPower")
@@ -538,8 +577,12 @@ class SqlitePreferences : Sqlite
 				preferences.showStiffness = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == "showInitialSpeed")
 				preferences.showInitialSpeed = reader[1].ToString() == "True";
-			else if(reader[0].ToString() == "showAngle")
-				preferences.showAngle = reader[1].ToString() == "True";
+			else if(reader[0].ToString() == ShowJumpRSI)
+				preferences.showJumpRSI = reader[1].ToString() == "True";
+			else if(reader[0].ToString() == "showAngle") {
+				//preferences.showAngle = reader[1].ToString() == "True";
+				preferences.showAngle = false;
+			}
 			else if(reader[0].ToString() == "showQIndex")
 				preferences.showQIndex = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == "showDjIndex")
@@ -800,6 +843,11 @@ class SqlitePreferences : Sqlite
 						Util.ChangeDecimalSeparator(reader[1].ToString()));
 
 			//runEncoder
+			else if(reader[0].ToString() == RunEncoderCaptureDisplaySimple)
+			{
+				preferences.runEncoderCaptureDisplaySimple = reader[1].ToString() == "True";
+				preferences.runEncoderCaptureDisplaySimpleStored = preferences.runEncoderCaptureDisplaySimple;
+			}
 			else if(reader[0].ToString() == RunEncoderMinAccel)
 				preferences.runEncoderMinAccel = Convert.ToDouble(
 						Util.ChangeDecimalSeparator(reader[1].ToString()));
@@ -844,8 +892,8 @@ class SqlitePreferences : Sqlite
 			else if(reader[0].ToString() == LoadLastModeAtStart)
 				preferences.loadLastModeAtStart = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == LastMode)
-				preferences.lastMode = (Constants.Menuitem_modes)
-					Enum.Parse(typeof(Constants.Menuitem_modes), reader[1].ToString());
+				preferences.lastMode = (Constants.Modes)
+					Enum.Parse(typeof(Constants.Modes), reader[1].ToString());
 			else if(reader[0].ToString() == SessionLoadDisplay)
 				preferences.sessionLoadDisplay = new SessionLoadDisplay(Convert.ToInt32(reader[1].ToString()));
 
