@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2019   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2022   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
@@ -329,7 +329,10 @@ class SqliteRunEncoder : Sqlite
 
 		//need to create an exercise to assign to the imported files
 		if(importedSomething)
-			SqliteRunEncoderExercise.Insert(true, 0, "Sprint", "", RunEncoderExercise.SegmentMetersDefault);
+		{
+			RunEncoderExercise ex = new RunEncoderExercise(0, "Sprint", "", RunEncoderExercise.SegmentCmDefault, new List<int>(), true);
+			ex.InsertSQL(true);
+		}
 
 		LogB.Information("end of import_from_1_70_to_1_71()");
 		//LogB.PrintAllThreads = false; //TODO: remove this
@@ -357,25 +360,23 @@ class SqliteRunEncoderExercise : Sqlite
 			"uniqueID INTEGER PRIMARY KEY, " +
 			"name TEXT, " +
 			"description TEXT, " +
-			"segmentMeters INT)";
+			"segmentMeters INT, " + 	//changed to cm in DB 2.33
+			"segmentVariableCm TEXT, " + 	//separator is ;
+			"isSprint INT NOT NULL DEFAULT 1)"; //bool
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 	}
 
 	//undefined defaultAngle will be 1000
 	//note execution can have a different angle than the default angle
-	public static int Insert (bool dbconOpened, int uniqueID, string name, string description, int segmentMeters)
+	public static int Insert (bool dbconOpened, string insertString)
 	{
 		if(! dbconOpened)
 			Sqlite.Open();
 
-		string uniqueIDStr = "NULL";
-		if(uniqueID != -1)
-			uniqueIDStr = uniqueID.ToString();
-
 		dbcmd.CommandText = "INSERT INTO " + table +
-				" (uniqueID, name, description, segmentMeters) VALUES (" +
-				uniqueIDStr + ", \"" + name + "\", \"" + description + "\", " + segmentMeters + ")";
+				" (uniqueID, name, description, segmentMeters, segmentVariableCm, isSprint)" +
+				" VALUES " + insertString;
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 
@@ -392,7 +393,8 @@ class SqliteRunEncoderExercise : Sqlite
 	//Default exercise for users without exercises (empty database creation or never used raceAnalyzer)
 	protected internal static void insertDefault ()
 	{
-		Insert (true, -1, "Sprint", "", RunEncoderExercise.SegmentMetersDefault);
+		RunEncoderExercise re = new RunEncoderExercise (-1, "Sprint", "", RunEncoderExercise.SegmentCmDefault, new List<int>(), true);
+		re.InsertSQL(true);
 	}
 
 	public static void Update (bool dbconOpened, RunEncoderExercise ex)
@@ -409,7 +411,9 @@ class SqliteRunEncoderExercise : Sqlite
 		dbcmd.CommandText = "UPDATE " + table + " SET " +
 			" name = \"" + ex.Name +
 			"\", description = \"" + ex.Description +
-			"\", segmentMeters = " + ex.SegmentMeters +
+			"\", segmentMeters = " + ex.SegmentCm + 	//cm since DB 2.33
+			", segmentVariableCm = \"" + ex.SegmentVariableCmToSQL +
+			"\", isSprint = " + Util.BoolToInt(ex.IsSprint) +
 			" WHERE uniqueID = " + ex.UniqueID;
 
 		LogB.SQL(dbcmd.CommandText.ToString());
@@ -432,7 +436,7 @@ class SqliteRunEncoderExercise : Sqlite
 	}
 
 
-	public static ArrayList Select (bool dbconOpened, int uniqueID, bool onlyNames)
+	public static List<RunEncoderExercise> Select (bool dbconOpened, int uniqueID)
 	{
 		if(! dbconOpened)
 			Sqlite.Open();
@@ -441,10 +445,7 @@ class SqliteRunEncoderExercise : Sqlite
 		if(uniqueID != -1)
 			uniqueIDStr = " WHERE " + table + ".uniqueID = " + uniqueID;
 
-		if(onlyNames)
-			dbcmd.CommandText = "SELECT name FROM " + table + uniqueIDStr;
-		else
-			dbcmd.CommandText = "SELECT * FROM " + table + uniqueIDStr;
+		dbcmd.CommandText = "SELECT * FROM " + table + uniqueIDStr;
 
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
@@ -452,33 +453,26 @@ class SqliteRunEncoderExercise : Sqlite
 		SqliteDataReader reader;
 		reader = dbcmd.ExecuteReader();
 
-		ArrayList array = new ArrayList(1);
-		RunEncoderExercise ex = new RunEncoderExercise();
+		List<RunEncoderExercise> list = new List<RunEncoderExercise>();
+		while(reader.Read()) {
+			//int angleDefault = 0;
 
-		if(onlyNames) {
-			while(reader.Read()) {
-				ex = new RunEncoderExercise (reader[0].ToString());
-				array.Add(ex);
-			}
-		} else {
-			while(reader.Read()) {
-				//int angleDefault = 0;
-
-				ex = new RunEncoderExercise (
-						Convert.ToInt32(reader[0].ToString()),	//uniqueID
-						reader[1].ToString(),			//name
-						reader[2].ToString(),			//description
-						Convert.ToInt32(reader[3].ToString())	//segmentMeters
-						);
-				array.Add(ex);
-			}
+			RunEncoderExercise ex = new RunEncoderExercise (
+					Convert.ToInt32(reader[0].ToString()),	//uniqueID
+					reader[1].ToString(),			//name
+					reader[2].ToString(),			//description
+					Convert.ToInt32(reader[3].ToString()),	//segmentCm (cm since DB 2.33)
+					Util.SQLStringToListInt(reader[4].ToString(), ";"),	//segmentVariableCm
+					Util.IntToBool(Convert.ToInt32(reader[5].ToString()))
+					);
+			list.Add(ex);
 		}
 
 		reader.Close();
 		if(! dbconOpened)
 			Sqlite.Close();
 
-		return array;
+		return list;
 	}
 
 }
