@@ -1052,7 +1052,7 @@ class SqliteSession : Sqlite
 			ArrayList encoderArray = SqliteEncoder.Select(
 					true, -1, -1, Convert.ToInt32(sessionID), Constants.EncoderGI.ALL,
 					-1, "signal", EncoderSQL.Eccons.ALL, "",
-					false, true);
+					false, true, false);
 
 			foreach(EncoderSQL eSQL in encoderArray) {
 				Util.FileDelete(eSQL.GetFullURL(false));	//signal, don't convertPathToR
@@ -1065,7 +1065,7 @@ class SqliteSession : Sqlite
 			encoderArray = SqliteEncoder.Select(
 					true, -1, -1, Convert.ToInt32(sessionID), Constants.EncoderGI.ALL,
 					-1, "curve",  EncoderSQL.Eccons.ALL, "",
-					false, true);
+					false, true, true);
 
 			foreach(EncoderSQL eSQL in encoderArray) {
 				Util.FileDelete(eSQL.GetFullURL(false));	//don't convertPathToR
