@@ -898,6 +898,13 @@ public class UtilGtk
 		return w.Allocation.Height;
 	}
 
+	public static Gdk.Pixbuf PixbufFromVBox (Gtk.VBox vbox)
+	{
+		return Gdk.Pixbuf.FromDrawable(vbox.GdkWindow, Gdk.Colormap.System,
+				vbox.Allocation.X, vbox.Allocation.Y, 0, 0,
+				WidgetWidth(vbox), WidgetHeight(vbox));
+	}
+
 	public static void IconWindow(Gtk.Window myWindow) {
 		Gdk.Pixbuf chronojumpIcon = new Gdk.Pixbuf (null, Constants.FileNameIcon);
             	myWindow.Icon = chronojumpIcon;
@@ -1007,7 +1014,9 @@ public class UtilGtk
 	
 	public static void ErasePaint(Gtk.DrawingArea da, Gdk.Pixmap px)
 	{
-		px.DrawRectangle (da.Style.WhiteGC, true, 0, 0, da.Allocation.Width, da.Allocation.Height);
+		if(px != null)
+			px.DrawRectangle (da.Style.WhiteGC, true, 0, 0, da.Allocation.Width, da.Allocation.Height);
+
 		da.QueueDraw(); // -- refresh
 	}
 	
