@@ -113,7 +113,6 @@ public class KeyDouble
 	}
 }
 
-/*
 public class TwoListsOfInts
 {
 	private string firstIntName; //just to be able to debug
@@ -160,8 +159,56 @@ public class TwoListsOfInts
 	{
 		return second_l[pos];
 	}
+
+	public override string ToString()
+	{
+		return (string.Format("firstIntName: {0}, secondIntName: {1}",
+					firstIntName, secondIntName)); // just to debug, add the values
+	}
+
+}
+
+public class TwoListsOfDoubles
+{
+	private List<double> first_l;
+	private List<double> second_l;
+
+	public TwoListsOfDoubles ()
+	{
+		Reset();
+	}
+
+	public void Reset()
+	{
+		first_l = new List<double>();
+		second_l = new List<double>();
+	}
+
+	public bool HasData()
+	{
+		return (first_l != null && first_l.Count > 0);
+	}
+
+	public int Count()
+	{
+		return first_l.Count;
+	}
+
+	public void Add (double addToFirst, double addToSecond)
+	{
+		first_l.Add(addToFirst);
+		second_l.Add(addToSecond);
+	}
+
+	public double GetFromFirst(int pos)
+	{
+		return first_l[pos];
+	}
+	public double GetFromSecond(int pos)
+	{
+		return second_l[pos];
+	}
 }
-*/
 
 //like Point but for having an xStart and xEnd
 public class PointStartEnd
@@ -553,6 +600,16 @@ public static class MathUtil
 		return ( Math.Abs(criteriaPassedValue - numToCompare) <= Math.Abs(previousToCriteriaValue - numToCompare) );
 	}
 
+	public static double GetMax (List<double> d_l)
+	{
+		double max = 0;
+		foreach (double d in d_l)
+			if ( d > max )
+				max = d;
+
+		return max;
+	}
+
 }
 
 public class InterpolateSignal
