@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -29,6 +29,7 @@ public abstract class WebcamFfmpegSupportedModes
 	protected string modesStr;
 	protected string errorStr;
 	protected string cameraCode;
+	protected bool testParsing = false; //ensure this is false on release
 
 	public abstract void GetModes();
 
@@ -82,7 +83,7 @@ public abstract class WebcamFfmpegSupportedModes
 		return wsm.FrameratesToStringList();
 	}
 
-	private WebcamSupportedModesList getListByPixelFormat(string pixelFormat)
+	protected WebcamSupportedModesList getListByPixelFormat(string pixelFormat)
 	{
 		if(pixelFormat == "" || wsmListOfLists == null || wsmListOfLists.Count == 0)
 			return new WebcamSupportedModesList();
@@ -94,6 +95,16 @@ public abstract class WebcamFfmpegSupportedModes
 		return new WebcamSupportedModesList();
 	}
 
+	public bool PixelFormatExists (string pixelFormat)
+	{
+		foreach(WebcamSupportedModesList wsmList in wsmListOfLists)
+			if(wsmList.PixelFormat == pixelFormat)
+				return true;
+
+		return false;
+	}
+
+
 	// ... end of: used to populated list on combos
 
 	protected abstract string parseSupportedModes(string allOutput);
@@ -118,7 +129,6 @@ public abstract class WebcamFfmpegSupportedModes
 			return nothingFound;
 	}
 
-	protected bool testParsing = true;
 	protected abstract string parseSupportedModesTestString();
 
 	public string ErrorStr
@@ -134,9 +144,10 @@ public abstract class WebcamFfmpegSupportedModes
 
 public class WebcamFfmpegSupportedModesLinux : WebcamFfmpegSupportedModes
 {
-	public WebcamFfmpegSupportedModesLinux()
+	public WebcamFfmpegSupportedModesLinux(string cameraCode)
 	{
 		initialize();
+		this.cameraCode = cameraCode;
 	}
 
 	public override void GetModes()
@@ -147,7 +158,11 @@ public class WebcamFfmpegSupportedModesLinux : WebcamFfmpegSupportedModes
 			return;
 		}
 
+		//v4l2-ctl -d 1 --list-formats-ext
+
 		List<string> parameters = new List<string>();
+		parameters.Add("-d");
+		parameters.Add(cameraCode);
 		parameters.Add("--list-formats-ext");
 		ExecuteProcess.Result execute_result = ExecuteProcess.run ("v4l2-ctl", parameters, true, true);
 		if(! execute_result.success) {
@@ -175,7 +190,7 @@ public class WebcamFfmpegSupportedModesLinux : WebcamFfmpegSupportedModes
 		{
 			LogB.Information("\nline: " + l);
 			//note v4l2-ctl packaged for Debian previous to buster prints "Pixel Format:", but on Buster is: "[0]: 'YUYV' (YUYV 4:2:2)"
-			if(l.Contains("Pixel Format:") || l.Contains("YUYV 4:2:2") || l.Contains("MJPG") || l.Contains("Motion-JPEG"))
+			if(l.Contains("Pixel Format:") || l.Contains("YUYV 4:2:2") || l.Contains("MJPG") || l.Contains("Motion-JPEG") || l.Contains("JPEG"))
 			{
 				wsmList = new WebcamSupportedModesList(parsePixelFormat(l));
 
@@ -186,7 +201,7 @@ public class WebcamFfmpegSupportedModesLinux : WebcamFfmpegSupportedModes
 			}
 
 			string resolutionStr = matchResolution(l);
-			if(wsmList != null && l.Contains("Size: Discrete") && resolutionStr != "")
+			if(wsmList != null && (l.Contains("Size: Discrete") || l.Contains("Size: Stepwise")) && resolutionStr != "")
 			{
 				LogB.Information("Is resolution!");
 				if(wsmList.ModeExist(resolutionStr))
@@ -214,12 +229,26 @@ public class WebcamFfmpegSupportedModesLinux : WebcamFfmpegSupportedModes
 
 	private string matchResolution(string l)
 	{
-		Match match = Regex.Match(l, @"(\d+)x(\d+)");
+		/*
+		 * on raspberry we found this string:
+		 * Size: Stepwise 32x32 - 2592x1944 width step 2/2
+		 * for this reason we use Regex.Matches instead of Regex.Match because we want to find all ocurrences, not just first one
+		 */
+		MatchCollection matches = Regex.Matches(l, @"(\d+)x(\d+)");
 
-		LogB.Information("resolution match group count is 3?", (match.Groups.Count == 3).ToString());
+		/*
+		LogB.Information(string.Format("resolution matches count: {0}", matches.Count));
 
-		if(match.Groups.Count == 3)
-			return string.Format("{0}x{1}", match.Groups[1].Value, match.Groups[2].Value);
+		foreach(Match m in matches)
+			LogB.Information(string.Format("match at foreachs: {0}", m));
+		*/
+
+		if(matches.Count > 0)
+		{
+			Match m = matches[matches.Count -1];
+			//LogB.Information(string.Format("final match: {0}x{1}", m.Groups[1].Value, m.Groups[2].Value));
+			return string.Format("{0}x{1}", m.Groups[1].Value, m.Groups[2].Value);
+		}
 
 		return "";
 	}
@@ -283,6 +312,8 @@ public class WebcamFfmpegSupportedModesLinux : WebcamFfmpegSupportedModes
 			return "yuyv422";
 		else if(m == "MJPG")
 			return "mjpeg";
+		else if(m == "JPEG")
+			return "mjpeg";
 		else
 			return string.Format("{0}", m);
 	}
@@ -316,6 +347,7 @@ ioctl: VIDIOC_ENUM_FMT
 			Interval: Discrete 0.040s (25.000 fps)
 			Interval: Discrete 0.050s (20.000 fps)
 			Interval: Discrete 0.067s (15.000 fps)
+		Size: Stepwise 32x32 - 2592x1944 width step 2/2
 ");
 	}
 }
@@ -338,7 +370,11 @@ public class WebcamFfmpegSupportedModesWindows : WebcamFfmpegSupportedModes
 			return;
 		}
 
-		string executable = System.IO.Path.Combine(Util.GetPrefixDir(), "bin/ffmpeg.exe");
+		string executable;
+		if(System.Environment.Is64BitProcess)
+			executable = System.IO.Path.Combine(Util.GetPrefixDir(), "bin/ffmpeg.exe");
+		else
+			executable = System.IO.Path.Combine(Util.GetPrefixDir(), "bin/i386/ffmpeg.exe");
 		//ffmpeg -f dshow -list_options true -i video="USB 2.0 WebCamera"
 		List<string> parameters = new List<string>();
 		parameters.Add("-f");
@@ -363,7 +399,6 @@ public class WebcamFfmpegSupportedModesWindows : WebcamFfmpegSupportedModes
 		modesStr = parseSupportedModes(execute_result.allOutput);
 	}
 
-	//TODO: have a class that sorts resolutions and framerates
 	protected override string parseSupportedModes(string allOutput)
 	{
 		/*
@@ -384,8 +419,17 @@ public class WebcamFfmpegSupportedModesWindows : WebcamFfmpegSupportedModes
 				string pixelFormat = parsePixelFormat(l);
 				if(pixelFormat != currentPixelFormat)
 				{
-					wsmList = new WebcamSupportedModesList(pixelFormat);
-					wsmListOfLists.Add(wsmList);
+					/*
+					 * on a Windows tablet the pixel formats came unsorted by pixel_format. Like this:
+					 * 1st pixelFormat line is from a pixel format, then from another, then the first from the first one ...
+					 * like the example on: parseSupportedModesTestString()
+					 */
+					if(PixelFormatExists(pixelFormat))
+						wsmList = getListByPixelFormat(pixelFormat);
+					else {
+						wsmList = new WebcamSupportedModesList(pixelFormat);
+						wsmListOfLists.Add(wsmList);
+					}
 					currentPixelFormat = pixelFormat;
 				}
 
@@ -438,7 +482,9 @@ public class WebcamFfmpegSupportedModesWindows : WebcamFfmpegSupportedModes
 	{
 		return(@"
 pixel_format=uyyv422  min s=176x144 fps=5 max s=176x144 fps=30
+pixel_format=nv  min s=600x300 fps=5 max s=600x300 fps=45
 pixel_format=uyyv422  min s=160x120 fps=5 max s=160x120 fps=30
+pixel_format=nv  min s=1200x900 fps=10 max s=1200x900 fps=50
 pixel_format=uyyv422  min s=320x240 fps=5 max s=320x240 fps=30");
 	}
 }
@@ -461,12 +507,28 @@ public class WebcamFfmpegSupportedModesMac : WebcamFfmpegSupportedModes
 			return;
 		}
 
+		/*
 		//select and impossible mode just to get an error on mac, this error will give us the "Supported modes"
 		Webcam webcamPlay = new WebcamFfmpeg (Webcam.Action.PLAYPREVIEW, UtilAll.GetOSEnum(),
 				cameraCode, "", "8000x8000", "8000");
+				*/
+
+		//Try with 640x480 at 30Hz
+		Webcam webcamPlay = new WebcamFfmpeg (Webcam.Action.PLAYPREVIEW, UtilAll.GetOSEnum(),
+				cameraCode, "", "640x480", "30");
 
 		Webcam.Result result = webcamPlay.PlayPreviewNoBackgroundWantStdoutAndStderr();
-		modesStr = parseSupportedModes(result.output);
+		if(result.success)
+		{
+			WebcamSupportedMode currentMode = new WebcamSupportedMode("640x480");
+			currentMode.AddFramerate("30");
+
+			WebcamSupportedModesList wsmList = new WebcamSupportedModesList("avfoundation");
+			wsmList.Add(currentMode);
+			wsmListOfLists.Add(wsmList);
+			modesStr = printListOfLists();
+		} else
+			modesStr = parseSupportedModes(result.output);
 	}
 
 	protected override string parseSupportedModes(string allOutput)
